@@ -4,21 +4,30 @@ Data Format (ASDF) files
 """
 
 __all__ = [
-    'AsdfFile', 'CustomType', 'AsdfExtension', 'Stream', 'open',
-    'commands', 'IntegerType', 'ExternalArrayReference', 'info', '__version__',
-    'ValidationError', 'get_config', 'config_context',
+    "AsdfFile",
+    "CustomType",
+    "AsdfExtension",
+    "Stream",
+    "open",
+    "IntegerType",
+    "ExternalArrayReference",
+    "info",
+    "__version__",
+    "ValidationError",
+    "get_config",
+    "config_context",
 ]
 
 
-from .asdf import AsdfFile, open_asdf as open
-from .types import CustomType
+from jsonschema import ValidationError
+
+from ._convenience import info
+from ._version import version as __version__
+from .asdf import AsdfFile
+from .asdf import open_asdf as open
+from .config import config_context, get_config
 from .extension import AsdfExtension
 from .stream import Stream
-from . import commands
 from .tags.core import IntegerType
 from .tags.core.external_reference import ExternalArrayReference
-from ._convenience import info
-from .config import get_config, config_context
-from .version import version as __version__
-
-from jsonschema import ValidationError
+from .types import CustomType
