@@ -144,6 +144,9 @@ def write_edited_yaml_larger(path, new_content, version):
                 blocks.write_block_index(fd, ctx)
                 blocks.close()
 
+            # the file needs to be closed here to release all memmaps
+            original_fd.close()
+
         # Swap in the new version of the file atomically:
         shutil.copy(temp_file.name, path)
     finally:
@@ -220,7 +223,7 @@ def edit(path):
                 new_asdf_version = parse_asdf_version(new_content)
                 new_yaml_version = parse_yaml_version(new_content)
             except Exception as e:
-                print("Error: failed to parse ASDF header: " + str(e))
+                print(f"Error: failed to parse ASDF header: {str(e)}")
                 choice = request_input("(c)ontinue editing or (a)bort? ", ["c", "a"])
                 if choice == "a":
                     return 1
