@@ -4,9 +4,8 @@ import sys
 
 from .. import util
 
-
 # This list is ordered in order of average workflow
-command_order = [ 'Explode', 'Implode' ]
+command_order = ["Explode", "Implode"]
 
 
 class Command:
@@ -24,27 +23,21 @@ def make_argparser():
     Most of the real work is handled by the subcommands in the
     commands subpackage.
     """
+
     def help(args):
         parser.print_help()
         return 0
 
-    parser = argparse.ArgumentParser(
-        "asdftool",
-        description="Commandline utilities for managing ASDF files.")
+    parser = argparse.ArgumentParser("asdftool", description="Commandline utilities for managing ASDF files.")
 
-    parser.add_argument(
-        "--verbose", "-v", action="store_true",
-        help="Increase verbosity")
+    parser.add_argument("--verbose", "-v", action="store_true", help="Increase verbosity")
 
-    subparsers = parser.add_subparsers(
-        title='subcommands',
-        description='valid subcommands')
+    subparsers = parser.add_subparsers(title="subcommands", description="valid subcommands")
 
-    help_parser = subparsers.add_parser(
-        str("help"), help="Display usage information")
+    help_parser = subparsers.add_parser("help", help="Display usage information")
     help_parser.set_defaults(func=help)
 
-    commands = dict((x.__name__, x) for x in util.iter_subclasses(Command))
+    commands = {x.__name__: x for x in util.iter_subclasses(Command)}
 
     for command in command_order:
         commands[str(command)].setup_arguments(subparsers)
@@ -62,7 +55,7 @@ def main_from_args(args):
     args = parser.parse_args(args)
 
     # Only needed for Python 3, apparently, but can't hurt
-    if not hasattr(args, 'func'):
+    if not hasattr(args, "func"):
         parser.print_help()
         return 2
 
@@ -71,7 +64,7 @@ def main_from_args(args):
     except RuntimeError as e:
         logging.error(str(e))
         return 1
-    except IOError as e:
+    except OSError as e:
         logging.error(str(e))
         return e.errno
 
