@@ -1,10 +1,6 @@
 import os
 
 import numpy as np
-
-import pytest
-
-astropy = pytest.importorskip('astropy')
 from astropy.io.fits import HDUList, ImageHDU
 
 import asdf
@@ -21,20 +17,17 @@ def test_extract(tmpdir):
     hdulist.append(image)
 
     tree = {
-        'some_words': 'These are some words',
-        'nested': {
-            'a': 100,
-            'b': 42
-        },
-        'list': [x for x in range(10)],
-        'image': image.data
+        "some_words": "These are some words",
+        "nested": {"a": 100, "b": 42},
+        "list": [x for x in range(10)],
+        "image": image.data,
     }
 
-    asdf_in_fits = str(tmpdir.join('asdf.fits'))
+    asdf_in_fits = str(tmpdir.join("asdf.fits"))
     with AsdfInFits(hdulist, tree) as aif:
         aif.write_to(asdf_in_fits)
 
-    pure_asdf = str(tmpdir.join('extract.asdf'))
+    pure_asdf = str(tmpdir.join("extract.asdf"))
     extract.extract_file(asdf_in_fits, pure_asdf)
 
     assert os.path.exists(pure_asdf)
