@@ -6,32 +6,39 @@ Contains commands for dealing with exploded and imploded forms.
 import os
 
 import asdf
-from .main import Command
+
 from .. import AsdfFile
+from .main import Command
 
-
-__all__ = ['to_yaml']
+__all__ = ["to_yaml"]
 
 
 class ToYaml(Command):
     @classmethod
     def setup_arguments(cls, subparsers):
         parser = subparsers.add_parser(
-            str("to_yaml"), help="Convert as ASDF file to pure YAML.",
+            "to_yaml",
+            help="Convert as ASDF file to pure YAML.",
             description="""Convert all data to inline YAML so the ASDF
-            file contains no binary blocks.""")
+            file contains no binary blocks.""",
+        )
 
+        parser.add_argument("filename", nargs=1, help="""The ASDF file to convert to YAML.""")
         parser.add_argument(
-            'filename', nargs=1,
-            help="""The ASDF file to convert to YAML.""")
-        parser.add_argument(
-            "--output", "-o", type=str, nargs="?",
+            "--output",
+            "-o",
+            type=str,
+            nargs="?",
             help="""The name of the output file.  If not provided, it
-            will be the name of the input file with a '.yaml' extension.""")
+            will be the name of the input file with a '.yaml' extension.""",
+        )
         parser.add_argument(
-            "--resolve-references", "-r", action="store_true",
+            "--resolve-references",
+            "-r",
+            action="store_true",
             help="""Resolve all references and store them directly in
-            the output file.""")
+            the output file.""",
+        )
 
         parser.set_defaults(func=cls.run)
 
@@ -60,9 +67,9 @@ def to_yaml(input, output=None, resolve_references=False):
     """
     if output is None:
         base, ext = os.path.splitext(input)
-        output = base + '.yaml'
+        output = base + ".yaml"
     with asdf.open(input) as ff:
         ff2 = AsdfFile(ff)
         if resolve_references:
             ff2.resolve_references()
-        ff2.write_to(output, all_array_storage='inline')
+        ff2.write_to(output, all_array_storage="inline")
