@@ -6,8 +6,8 @@ from collections import OrderedDict
 from collections.abc import Mapping
 from functools import lru_cache
 from numbers import Integral
+from operator import methodcaller
 
-import attr
 import numpy as np
 import yaml
 from jsonschema import validators as mvalidators
@@ -84,13 +84,11 @@ def validate_tag(validator, tag_pattern, instance, schema):
 
     if instance_tag is None:
         yield ValidationError(
-            "mismatched tags, wanted '{}', got unhandled object type '{}'".format(
-                tag_pattern, util.get_class_name(instance)
-            )
+            f"mismatched tags, wanted '{tag_pattern}', got unhandled object type '{util.get_class_name(instance)}'"
         )
 
     if not util.uri_match(tag_pattern, instance_tag):
-        yield ValidationError("mismatched tags, wanted '{0}', got '{1}'".format(tag_pattern, instance_tag))
+        yield ValidationError(f"mismatched tags, wanted '{tag_pattern}', got '{instance_tag}'")
 
 
 def validate_propertyOrder(validator, order, instance, schema):
@@ -152,6 +150,17 @@ def validate_type(validator, types, instance, schema):
     return mvalidators.Draft4Validator.VALIDATORS["type"](validator, types, instance, schema)
 
 
+def validate_enum(validator, enums, instance, schema):
+    """
+    `asdf.tagged.Tagged` objects will fail in the default enum validator
+    """
+
+    if isinstance(instance, tagged.Tagged):
+        instance = instance.base
+
+    yield from mvalidators.Draft4Validator.VALIDATORS["enum"](validator, enums, instance, schema)
+
+
 YAML_VALIDATORS = util.HashableDict(mvalidators.Draft4Validator.VALIDATORS.copy())
 YAML_VALIDATORS.update(
     {
@@ -160,6 +169,7 @@ YAML_VALIDATORS.update(
         "flowStyle": validate_flowStyle,
         "style": validate_style,
         "type": validate_type,
+        "enum": validate_enum,
     }
 )
 
@@ -172,8 +182,7 @@ def validate_fill_default(validator, properties, instance, schema):
         if "default" in subschema:
             instance.setdefault(property, subschema["default"])
 
-    for err in mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema):
-        yield err
+    yield from mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema)
 
 
 FILL_DEFAULTS = util.HashableDict()
@@ -191,8 +200,7 @@ def validate_remove_default(validator, properties, instance, schema):
             if instance.get(property, None) == subschema["default"]:
                 del instance[property]
 
-    for err in mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema):
-        yield err
+    yield from mvalidators.Draft4Validator.VALIDATORS["properties"](validator, properties, instance, schema)
 
 
 REMOVE_DEFAULTS = util.HashableDict()
@@ -243,7 +251,7 @@ class _ValidationContext:
         return (id(instance), id(schema))
 
 
-@lru_cache()
+@lru_cache
 def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
     meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, extension.get_default_resolver(), False, False)
 
@@ -255,15 +263,25 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
         }
     )
     id_of = mvalidators.Draft4Validator.ID_OF
-    base_cls = mvalidators.create(
+    ASDFValidator = mvalidators.create(
         meta_schema=meta_schema, validators=validators, type_checker=type_checker, id_of=id_of
     )
 
-    @attr.s
-    class ASDFValidator(base_cls):
-        _context = attr.ib(factory=lambda: _ValidationContext())
-        ctx = attr.ib(default=None)
-        serialization_context = attr.ib(default=None)
+    def _patch_init(cls):
+        original_init = cls.__init__
+
+        def __init__(self, *args, **kwargs):
+            self.ctx = kwargs.pop("ctx", None)
+            self.serialization_context = kwargs.pop("serialization_context", None)
+
+            original_init(self, *args, **kwargs)
+
+        cls.__init__ = __init__
+
+    def _patch_iter_errors(cls):
+        original_iter_errors = cls.iter_errors
+
+        cls._context = _ValidationContext()
 
         def iter_errors(self, instance, *args, **kwargs):
             # We can't validate anything that looks like an external reference,
@@ -299,28 +317,30 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
                                 with self.resolver.resolving(schema_uri) as resolved:
                                     yield from self.descend(instance, resolved)
                             except RefResolutionError:
-                                msg = "Unable to locate schema file for '{}': '{}'"
-                                warnings.warn(msg.format(tag, schema_uri), AsdfWarning)
+                                warnings.warn(f"Unable to locate schema file for '{tag}': '{schema_uri}'", AsdfWarning)
 
                     if isinstance(instance, dict):
                         for val in instance.values():
-                            for x in self.iter_errors(val):
-                                yield x
+                            yield from self.iter_errors(val)
 
                     elif isinstance(instance, list):
                         for val in instance:
-                            for x in self.iter_errors(val):
-                                yield x
+                            yield from self.iter_errors(val)
                 else:
-                    yield from super(ASDFValidator, self).iter_errors(instance)
+                    yield from original_iter_errors(self, instance)
+
+        cls.iter_errors = iter_errors
+
+    _patch_init(ASDFValidator)
+    _patch_iter_errors(ASDFValidator)
 
     return ASDFValidator
 
 
-@lru_cache()
+@lru_cache
 def _load_schema(url):
     if url.startswith("http://") or url.startswith("https://") or url.startswith("asdf://"):
-        raise FileNotFoundError("Unable to fetch schema from non-file URL: " + url)
+        raise FileNotFoundError(f"Unable to fetch schema from non-file URL: {url}")
 
     with generic_io.get_file(url) as fd:
         if isinstance(url, str) and url.endswith("json"):
@@ -388,10 +408,10 @@ def _make_resolver(url_mapping):
     )
 
 
-@lru_cache()
+@lru_cache
 def load_custom_schema(url):
     warnings.warn(
-        "The 'load_custom_schema(...)' function is deprecated. Use" "'load_schema' instead.", AsdfDeprecationWarning
+        "The 'load_custom_schema(...)' function is deprecated. Use 'load_schema' instead.", AsdfDeprecationWarning
     )
     return load_schema(url, resolve_references=True)
 
@@ -476,7 +496,7 @@ def _safe_resolve(resolver, json_id, uri):
     return base, fragment
 
 
-@lru_cache()
+@lru_cache
 def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
     loader = _make_schema_loader(resolver)
     schema, url = loader(url)
@@ -523,7 +543,7 @@ def get_validator(
     Get a JSON schema validator object for the given schema.
 
     The additional *args and **kwargs are passed along to
-    `jsonschema.validate`.
+    `~jsonschema.Validator.validate`.
 
     Parameters
     ----------
@@ -592,7 +612,7 @@ def _validate_large_literals(instance, reading):
                 AsdfWarning,
             )
         else:
-            raise ValidationError(f"Integer value {value} is too large to safely represent as a " "literal in ASDF")
+            raise ValidationError(f"Integer value {value} is too large to safely represent as a literal in ASDF")
 
     if isinstance(instance, Integral):
         _validate(instance)
@@ -621,7 +641,7 @@ def _validate_mapping_keys(instance, reading):
                     AsdfWarning,
                 )
             else:
-                raise ValidationError(f"Mapping key {key} is not permitted.  Valid types: " "str, int, bool.")
+                raise ValidationError(f"Mapping key {key} is not permitted.  Valid types: str, int, bool.")
 
 
 def validate(instance, ctx=None, schema={}, validators=None, reading=False, *args, **kwargs):
@@ -630,8 +650,8 @@ def validate(instance, ctx=None, schema={}, validators=None, reading=False, *arg
     the appropriate schema.  The schema itself is located using the
     tag on the instance.
 
-    The additional *args and **kwargs are passed along to
-    `jsonschema.validate`.
+    The additional ``*args`` and ``**kwargs`` are passed along to
+    `~jsonschema.Validator.validate`.
 
     Parameters
     ----------
@@ -713,7 +733,7 @@ def check_schema(schema, validate_default=True):
     Parameters
     ----------
     schema : dict
-        The schema object, as returned by `load_schema`.
+        The schema object, as returned by ``load_schema``.
     validate_default : bool, optional
         Set to `True` to validate the content of the default
         field against the schema.
@@ -739,6 +759,14 @@ def check_schema(schema, validate_default=True):
 
         validators.update({"default": _validate_default})
 
+        def applicable_validators(schema):
+            items = list(schema.items())
+            items.append(("default", ""))
+            return items
+
+    else:
+        applicable_validators = methodcaller("items")
+
     meta_schema_id = schema.get("$schema", YAML_SCHEMA_METASCHEMA_ID)
     meta_schema = _load_schema_cached(meta_schema_id, extension.get_default_resolver(), False, False)
 
@@ -749,6 +777,7 @@ def check_schema(schema, validate_default=True):
         validators=validators,
         type_checker=mvalidators.Draft4Validator.TYPE_CHECKER,
         id_of=mvalidators.Draft4Validator.ID_OF,
+        applicable_validators=applicable_validators,
     )
     validator = cls(meta_schema, resolver=resolver)
     validator.validate(schema)
