@@ -31,7 +31,7 @@ is not intended to be exposed to the end user.
 from collections import UserDict, UserList, UserString
 from copy import copy, deepcopy
 
-__all__ = ["tag_object", "get_tag"]
+__all__ = ["tag_object", "get_tag", "Tagged", "TaggedDict", "TaggedList", "TaggedString"]
 
 
 class Tagged:
@@ -40,7 +40,13 @@ class Tagged:
     with it.
     """
 
-    pass
+    _base_type = None
+
+    @property
+    def base(self):
+        """Convert to base type"""
+
+        return self._base_type(self)
 
 
 class TaggedDict(Tagged, UserDict, dict):
@@ -48,6 +54,8 @@ class TaggedDict(Tagged, UserDict, dict):
     A Python dict with a tag attached.
     """
 
+    _base_type = dict
+
     flow_style = None
     property_order = None
 
@@ -74,6 +82,8 @@ class TaggedList(Tagged, UserList, list):
     A Python list with a tag attached.
     """
 
+    _base_type = list
+
     flow_style = None
 
     def __init__(self, data=None, tag=None):
@@ -99,6 +109,8 @@ class TaggedString(Tagged, UserString, str):
     A Python string with a tag attached.
     """
 
+    _base_type = str
+
     style = None
 
     def __eq__(self, other):
@@ -126,7 +138,7 @@ def tag_object(tag, instance, ctx=None):
         try:
             instance = yamlutil.custom_tree_to_tagged_tree(instance, ctx)
         except TypeError:
-            raise TypeError("Don't know how to tag a {0}".format(type(instance)))
+            raise TypeError(f"Don't know how to tag a {type(instance)}")
         instance._tag = tag
     return instance
 
