@@ -1,12 +1,12 @@
 import numpy as np
 
-from ...types import AsdfType
 from ... import util
+from ...types import AsdfType
 
 
 class ComplexType(AsdfType):
-    name = 'core/complex'
-    version = '1.0.0'
+    name = "core/complex"
+    version = "1.0.0"
     types = list(util.iter_subclasses(np.complexfloating)) + [complex]
 
     @classmethod
@@ -15,9 +15,5 @@ class ComplexType(AsdfType):
 
     @classmethod
     def from_tree(cls, tree, ctx):
-        tree = tree.replace(
-            'inf', 'INF').replace(
-            'i', 'j').replace(
-            'INF', 'inf').replace(
-            'I', 'J')
+        tree = tree.replace("inf", "INF").replace("i", "j").replace("INF", "inf").replace("I", "J")
         return complex(tree)
