@@ -3,7 +3,7 @@ from asdf.tests import helpers
 
 
 def test_roundtrip_external_array(tmpdir):
-    ref = ExternalArrayReference("./nonexistant.fits", 1, "np.float64", (100, 100))
+    ref = ExternalArrayReference("./nonexistent.fits", 1, "np.float64", (100, 100))
 
     tree = {"nothere": ref}
 
