@@ -1,20 +1,18 @@
-import os
 import datetime
 import fractions
+import os
 
 import pytest
-
 from jsonschema import ValidationError
 
 import asdf
-from asdf import util
-from asdf import types
-from asdf.tests import helpers
-from asdf.tests.helpers import yaml_to_asdf, assert_no_warnings
-from asdf.tags.core import HistoryEntry
+from asdf import types, util
 from asdf.exceptions import AsdfWarning
+from asdf.tags.core import HistoryEntry
+from asdf.tests import helpers
+from asdf.tests.helpers import assert_no_warnings, yaml_to_asdf
 
-SCHEMA_PATH = os.path.join(os.path.dirname(helpers.__file__), 'data')
+SCHEMA_PATH = os.path.join(os.path.dirname(helpers.__file__), "data")
 
 
 class CustomExtension:
@@ -22,72 +20,66 @@ class CustomExtension:
     This is the base class that is used for extensions for custom tag
     classes that exist only for the purposes of testing.
     """
+
     @property
     def types(self):
         return []
 
     @property
     def tag_mapping(self):
-        return [('tag:nowhere.org:custom',
-                 'http://nowhere.org/schemas/custom{tag_suffix}')]
+        return [("tag:nowhere.org:custom", "http://nowhere.org/schemas/custom{tag_suffix}")]
 
     @property
     def url_mapping(self):
-        return [('http://nowhere.org/schemas/custom/',
-                 util.filepath_to_url(SCHEMA_PATH) +
-                 '/{url_suffix}.yaml')]
+        return [("http://nowhere.org/schemas/custom/", util.filepath_to_url(SCHEMA_PATH) + "/{url_suffix}.yaml")]
 
 
 def test_history():
     ff = asdf.AsdfFile()
-    assert 'history' not in ff.tree
-    ff.add_history_entry('This happened',
-                         {'name': 'my_tool',
-                          'homepage': 'http://nowhere.org',
-                          'author': 'John Doe',
-                          'version': '2.0'})
-    assert len(ff.tree['history']['entries']) == 1
+    assert "history" not in ff.tree
+    ff.add_history_entry(
+        "This happened", {"name": "my_tool", "homepage": "http://nowhere.org", "author": "John Doe", "version": "2.0"}
+    )
+    assert len(ff.tree["history"]["entries"]) == 1
 
     with pytest.raises(ValidationError):
-        ff.add_history_entry('That happened',
-                             {'author': 'John Doe',
-                              'version': '2.0'})
-    assert len(ff.tree['history']['entries']) == 1
+        ff.add_history_entry("That happened", {"author": "John Doe", "version": "2.0"})
+    assert len(ff.tree["history"]["entries"]) == 1
 
-    ff.add_history_entry('This other thing happened')
-    assert len(ff.tree['history']['entries']) == 2
+    ff.add_history_entry("This other thing happened")
+    assert len(ff.tree["history"]["entries"]) == 2
+
+    assert isinstance(ff.tree["history"]["entries"][0]["time"], datetime.datetime)
 
-    assert isinstance(ff.tree['history']['entries'][0]['time'], datetime.datetime)
 
 def test_history_to_file(tmpdir):
 
-    tmpfile = str(tmpdir.join('history.asdf'))
+    tmpfile = str(tmpdir.join("history.asdf"))
 
     with asdf.AsdfFile() as ff:
-        ff.add_history_entry('This happened',
-                             {'name': 'my_tool',
-                              'homepage': 'http://nowhere.org',
-                              'author': 'John Doe',
-                              'version': '2.0'})
+        ff.add_history_entry(
+            "This happened",
+            {"name": "my_tool", "homepage": "http://nowhere.org", "author": "John Doe", "version": "2.0"},
+        )
         ff.write_to(tmpfile)
 
     with asdf.open(tmpfile) as ff:
-        assert 'entries' in ff.tree['history']
-        assert 'extensions' in ff.tree['history']
-        assert len(ff.tree['history']['entries']) == 1
+        assert "entries" in ff.tree["history"]
+        assert "extensions" in ff.tree["history"]
+        assert len(ff.tree["history"]["entries"]) == 1
 
-        entry = ff.tree['history']['entries'][0]
-        assert entry['description'] == 'This happened'
-        assert entry['software']['name'] == 'my_tool'
-        assert entry['software']['version'] == '2.0'
+        entry = ff.tree["history"]["entries"][0]
+        assert entry["description"] == "This happened"
+        assert entry["software"]["name"] == "my_tool"
+        assert entry["software"]["version"] == "2.0"
 
         # Test the history entry retrieval API
         entries = ff.get_history_entries()
         assert len(entries) == 1
         assert isinstance(entries, list)
         assert isinstance(entries[0], HistoryEntry)
-        assert entries[0]['description'] == "This happened"
-        assert entries[0]['software']['name'] == 'my_tool'
+        assert entries[0]["description"] == "This happened"
+        assert entries[0]["software"]["name"] == "my_tool"
 
 
 def test_old_history(tmpdir):
@@ -104,29 +96,30 @@ history:
 
     buff = yaml_to_asdf(yaml)
     with asdf.open(buff) as af:
-        assert len(af.tree['history']) == 1
+        assert len(af.tree["history"]) == 1
 
         # Test the history entry retrieval API
         entries = af.get_history_entries()
         assert len(entries) == 1
         assert isinstance(entries, list)
         assert isinstance(entries[0], HistoryEntry)
-        assert entries[0]['description'] == "Here's a test of old history entries"
-        assert entries[0]['software']['name'] == 'foo'
+        assert entries[0]["description"] == "Here's a test of old history entries"
+        assert entries[0]["software"]["name"] == "foo"
+
 
 def test_get_history_entries(tmpdir):
     """
     Test edge cases for the get_history_entries API. Other cases tested above
     """
 
-    tmpfile = str(tmpdir.join('empty.asdf'))
+    tmpfile = str(tmpdir.join("empty.asdf"))
 
     with asdf.AsdfFile() as af:
         af.write_to(tmpfile)
 
     # Make sure this works when there is no history section at all
     with asdf.open(tmpfile) as af:
-        assert len(af['history']['extensions']) > 0
+        assert len(af["history"]["extensions"]) > 0
         assert len(af.get_history_entries()) == 0
 
 
@@ -134,16 +127,16 @@ def test_extension_metadata(tmpdir):
 
     ff = asdf.AsdfFile()
 
-    tmpfile = str(tmpdir.join('extension.asdf'))
+    tmpfile = str(tmpdir.join("extension.asdf"))
     ff.write_to(tmpfile)
 
     with asdf.open(tmpfile) as af:
-        assert len(af.tree['history']['extensions']) == 1
-        metadata = af.tree['history']['extensions'][0]
-        assert metadata.extension_class == 'asdf.extension.BuiltinExtension'
+        assert len(af.tree["history"]["extensions"]) == 1
+        metadata = af.tree["history"]["extensions"][0]
+        assert metadata.extension_class == "asdf.extension.BuiltinExtension"
         # Don't bother with testing the version here since it will depend on
         # how recently the package was built (version is auto-generated)
-        assert metadata.software['name'] == 'asdf'
+        assert metadata.software["name"] == "asdf"
 
 
 def test_missing_extension_warning():
@@ -159,7 +152,7 @@ history:
     """
 
     buff = yaml_to_asdf(yaml)
-    with pytest.warns(AsdfWarning, match="File was created with extension class 'foo.bar.FooBar'"):
+    with pytest.warns(AsdfWarning, match=r"File was created with extension class 'foo.bar.FooBar'"):
         with asdf.open(buff):
             pass
 
@@ -177,7 +170,7 @@ history:
     """
 
     buff = yaml_to_asdf(yaml)
-    with pytest.warns(AsdfWarning, match="File was created with extension class 'asdf.extension.BuiltinExtension'"):
+    with pytest.warns(AsdfWarning, match=r"File was created with extension class 'asdf.extension.BuiltinExtension'"):
         with asdf.open(buff):
             pass
 
@@ -214,12 +207,11 @@ history:
 
 
 def test_metadata_with_custom_extension(tmpdir):
-
     class FractionType(types.CustomType):
-        name = 'fraction'
-        organization = 'nowhere.org'
+        name = "fraction"
+        organization = "nowhere.org"
         version = (1, 0, 0)
-        standard = 'custom'
+        standard = "custom"
         types = [fractions.Fraction]
 
         @classmethod
@@ -235,41 +227,39 @@ def test_metadata_with_custom_extension(tmpdir):
         def types(self):
             return [FractionType]
 
-    tree = {
-        'fraction': fractions.Fraction(2, 3)
-    }
+    tree = {"fraction": fractions.Fraction(2, 3)}
 
-    tmpfile = str(tmpdir.join('custom_extension.asdf'))
+    tmpfile = str(tmpdir.join("custom_extension.asdf"))
     with asdf.AsdfFile(tree, extensions=FractionExtension()) as ff:
         ff.write_to(tmpfile)
 
     # We expect metadata about both the Builtin extension and the custom one
     with asdf.open(tmpfile, extensions=FractionExtension()) as af:
-        assert len(af['history']['extensions']) == 2
+        assert len(af["history"]["extensions"]) == 2
 
-    with pytest.warns(AsdfWarning, match="was created with extension"):
+    with pytest.warns(AsdfWarning, match=r"was created with extension"):
         with asdf.open(tmpfile, ignore_unrecognized_tag=True):
             pass
 
     # If we use the extension but we don't serialize any types that require it,
     # no metadata about this extension should be added to the file
-    tree2 = { 'x': [x for x in range(10)] }
-    tmpfile2 = str(tmpdir.join('no_extension.asdf'))
+    tree2 = {"x": [x for x in range(10)]}
+    tmpfile2 = str(tmpdir.join("no_extension.asdf"))
     with asdf.AsdfFile(tree2, extensions=FractionExtension()) as ff:
         ff.write_to(tmpfile2)
 
     with asdf.open(tmpfile2) as af:
-        assert len(af['history']['extensions']) == 1
+        assert len(af["history"]["extensions"]) == 1
 
     with assert_no_warnings():
         with asdf.open(tmpfile2):
             pass
 
     # Make sure that this works even when constructing the tree on-the-fly
-    tmpfile3 = str(tmpdir.join('custom_extension2.asdf'))
+    tmpfile3 = str(tmpdir.join("custom_extension2.asdf"))
     with asdf.AsdfFile(extensions=FractionExtension()) as ff:
-        ff.tree['fraction'] = fractions.Fraction(4, 5)
+        ff.tree["fraction"] = fractions.Fraction(4, 5)
         ff.write_to(tmpfile3)
 
     with asdf.open(tmpfile3, extensions=FractionExtension()) as af:
-        assert len(af['history']['extensions']) == 2
+        assert len(af["history"]["extensions"]) == 2
