@@ -79,8 +79,8 @@ def test_sharing(tmpdir):
 
 def test_byteorder(tmpdir):
     tree = {
-        "bigendian": np.arange(0, 10, dtype=str(">f8")),
-        "little": np.arange(0, 10, dtype=str("<f8")),
+        "bigendian": np.arange(0, 10, dtype=">f8"),
+        "little": np.arange(0, 10, dtype="<f8"),
     }
 
     def check_asdf(asdf):
@@ -145,7 +145,7 @@ def test_dont_load_data():
 def test_table_inline(tmpdir):
     table = np.array(
         [(0, 1, (2, 3)), (4, 5, (6, 7))],
-        dtype=[(str("MINE"), np.int8), (str(""), np.float64), (str("arr"), ">i4", (2,))],
+        dtype=[("MINE", np.int8), ("", np.float64), ("arr", ">i4", (2,))],
     )
 
     tree = {"table_data": table}
@@ -198,9 +198,7 @@ x0: !core/ndarray-1.0.0
 
 
 def test_table(tmpdir):
-    table = np.array(
-        [(0, 1, (2, 3)), (4, 5, (6, 7))], dtype=[(str("MINE"), np.int8), (str(""), "<f8"), (str("arr"), ">i4", (2,))]
-    )
+    table = np.array([(0, 1, (2, 3)), (4, 5, (6, 7))], dtype=[("MINE", np.int8), ("", "<f8"), ("arr", ">i4", (2,))])
 
     tree = {"table_data": table}
 
@@ -224,7 +222,7 @@ def test_table(tmpdir):
 def test_table_nested_fields(tmpdir):
     table = np.array(
         [(0, (1, 2)), (4, (5, 6)), (7, (8, 9))],
-        dtype=[(str("A"), "<i8"), (str("B"), [(str("C"), "<i8"), (str("D"), "<i8")])],
+        dtype=[("A", "<i8"), ("B", [("C", "<i8"), ("D", "<i8")])],
     )
 
     tree = {"table_data": table}
@@ -381,11 +379,11 @@ def test_simple_table():
             (10.687610626220703, 41.270301818847656, 0.18, 0.14, 60.192),
         ],
         dtype=[
-            (str("ra"), str("<f4")),
-            (str("dec"), str("<f4")),
-            (str("err_maj"), str("<f8")),
-            (str("err_min"), str("<f8")),
-            (str("angle"), str("<f8")),
+            ("ra", "<f4"),
+            ("dec", "<f4"),
+            ("err_maj", "<f8"),
+            ("err_min", "<f8"),
+            ("angle", "<f8"),
         ],
     )
 
@@ -447,6 +445,37 @@ def test_masked_array_stay_open_bug(tmpdir):
     assert len(p.open_files()) <= len(orig_open)
 
 
+def test_memmap_stay_open_bug(tmpdir):
+    """
+    Regression test for issue #1239
+    memmapped arrays only closed at garbage collection when asdf.open given an open file
+
+    When asdf.open is called with an already opened file
+    it did not close any memmaps that it created (as the file
+    pointer was still valid). These lingered until garbage collection
+    and caused CI failures in astropy:
+    https://github.com/astropy/astropy/pull/14035#issuecomment-1325236928
+    """
+    psutil = pytest.importorskip("psutil")
+
+    tmppath = os.path.join(str(tmpdir), "arr.asdf")
+
+    tree = {"test": np.array([1, 2, 3])}
+
+    f = asdf.AsdfFile(tree)
+    f.write_to(tmppath)
+
+    p = psutil.Process()
+    orig_open = p.open_files()
+
+    for i in range(3):
+        with open(tmppath, mode="rb") as fp:
+            with asdf.open(fp) as f2:
+                np.sum(f2.tree["test"])
+
+    assert len(p.open_files()) <= len(orig_open)
+
+
 def test_masked_array_repr(tmpdir):
     tmppath = os.path.join(str(tmpdir), "masked.asdf")
 
@@ -733,9 +762,9 @@ def test_structured_datatype_validation(tmpdir):
 
 def test_string_inline():
     x = np.array([b"a", b"b", b"c"])
-    l = ndarray.numpy_array_to_list(x)
+    line = ndarray.numpy_array_to_list(x)
 
-    for entry in l:
+    for entry in line:
         assert isinstance(entry, str)
 
 
@@ -798,15 +827,45 @@ def test_non_contiguous_base_array(tmpdir):
 
 
 def test_fortran_order(tmpdir):
-    array = np.array([[11, 12, 13], [21, 22, 23]], order="F")
+    array = np.array([[11, 12, 13], [21, 22, 23]], order="F", dtype=np.int64)
     tree = dict(data=array)
-    helpers.assert_roundtrip_tree(tree, tmpdir)
+
+    def check_f_order(t):
+        assert t["data"].flags.fortran
+        assert np.all(np.isclose(array, t["data"]))
+
+    def check_raw_yaml(content):
+        tree = yaml.safe_load(re.sub(rb"!core/\S+", b"", content))
+        assert tree["data"]["strides"] == [8, 16]
+
+    helpers.assert_roundtrip_tree(tree, tmpdir, asdf_check_func=check_f_order, raw_yaml_check_func=check_raw_yaml)
+
+
+def test_memmap_write(tmpdir):
+    tmpfile = str(tmpdir.join("data.asdf"))
+    tree = dict(data=np.zeros(100))
+
+    with asdf.AsdfFile(tree) as af:
+        # Make sure we're actually writing to an internal array for this test
+        af.write_to(tmpfile, all_array_storage="internal")
+
+    with asdf.open(tmpfile, mode="rw", copy_arrays=False) as af:
+        data = af["data"]
+        assert data.flags.writeable is True
+        data[0] = 42
+        assert data[0] == 42
+
+    with asdf.open(tmpfile, mode="rw", copy_arrays=False) as af:
+        assert af["data"][0] == 42
+
+    with asdf.open(tmpfile, mode="r", copy_arrays=False) as af:
+        assert af["data"][0] == 42
 
 
 def test_readonly(tmpdir):
 
     tmpfile = str(tmpdir.join("data.asdf"))
-    tree = dict(data=np.ndarray((100)))
+    tree = dict(data=np.ndarray(100))
 
     with asdf.AsdfFile(tree) as af:
         # Make sure we're actually writing to an internal array for this test
@@ -814,48 +873,53 @@ def test_readonly(tmpdir):
 
     # Opening in read mode (the default) should mean array is readonly
     with asdf.open(tmpfile) as af:
-        assert af["data"].flags.writeable == False
+        assert af["data"].flags.writeable is False
         with pytest.raises(ValueError) as err:
             af["data"][0] = 41
             assert str(err) == "assignment destination is read-only"
 
     # This should be perfectly fine
     with asdf.open(tmpfile, mode="rw") as af:
-        assert af["data"].flags.writeable == True
+        assert af["data"].flags.writeable is True
         af["data"][0] = 40
 
     # Copying the arrays makes it safe to write to the underlying array
     with asdf.open(tmpfile, mode="r", copy_arrays=True) as af:
-        assert af["data"].flags.writeable == True
+        assert af["data"].flags.writeable is True
         af["data"][0] = 42
 
 
 def test_readonly_inline(tmpdir):
     tmpfile = str(tmpdir.join("data.asdf"))
-    tree = dict(data=np.ndarray((100)))
+    tree = dict(data=np.ndarray(100))
 
     with asdf.AsdfFile(tree) as af:
         af.write_to(tmpfile, all_array_storage="inline")
 
     # This should be safe since it's an inline array
     with asdf.open(tmpfile, mode="r") as af:
-        assert af["data"].flags.writeable == True
+        assert af["data"].flags.writeable is True
         af["data"][0] = 42
 
 
 # Confirm that NDArrayType's internal array is regenerated
 # following an update.
-def test_block_data_change(tmpdir):
+@pytest.mark.parametrize("pad_blocks", [True, False])
+def test_block_data_change(pad_blocks, tmpdir):
     tmpfile = str(tmpdir.join("data.asdf"))
-    tree = {"data": np.ndarray(10)}
+    tree = {"data": np.zeros(10, dtype="uint8")}
     with asdf.AsdfFile(tree) as af:
-        af.write_to(tmpfile)
+        af.write_to(tmpfile, pad_blocks=pad_blocks)
 
     with asdf.open(tmpfile, mode="rw") as af:
+        assert np.all(af.tree["data"] == 0)
         array_before = af.tree["data"].__array__()
+        af.tree["data"][:5] = 1
         af.update()
         array_after = af.tree["data"].__array__()
         assert array_before is not array_after
+        assert np.all(af.tree["data"][:5] == 1)
+        assert np.all(af.tree["data"][5:] == 0)
 
 
 def test_problematic_class_attributes(tmp_path):
