@@ -31,7 +31,13 @@ from ..exceptions import AsdfConversionWarning
 from ..extension import default_extensions
 from ..resolver import Resolver, ResolverChain
 from ..tags.core import AsdfObject
-from ..versioning import AsdfVersion, get_version_map
+from ..versioning import (
+    AsdfVersion,
+    asdf_standard_development_version,
+    get_version_map,
+    split_tag_version,
+    supported_versions,
+)
 from .httpserver import RangeHTTPServer
 
 try:
@@ -80,7 +86,7 @@ def assert_tree_match(old_tree, new_tree, ctx=None, funcname="assert_equal", ign
     funcname : `str` or `callable`
         The name of a method on members of old_tree and new_tree that
         will be used to compare custom objects.  The default of
-        `assert_equal` handles Numpy arrays.
+        ``assert_equal`` handles Numpy arrays.
 
     ignore_keys : list of str
         List of keys to ignore
@@ -119,9 +125,7 @@ def assert_tree_match(old_tree, new_tree, ctx=None, funcname="assert_equal", ign
                 getattr(old_type, funcname)(old, new)
 
         elif isinstance(old, dict) and isinstance(new, dict):
-            assert set(x for x in old.keys() if x not in ignore_keys) == set(
-                x for x in new.keys() if x not in ignore_keys
-            )
+            assert {x for x in old.keys() if x not in ignore_keys} == {x for x in new.keys() if x not in ignore_keys}
             for key in old.keys():
                 if key not in ignore_keys:
                     recurse(old[key], new[key])
@@ -154,7 +158,7 @@ def assert_roundtrip_tree(*args, **kwargs):
 
     tree : ASDF tree
 
-    tmpdir : str
+    tmp_path : `str` or `pathlib.Path`
         Path to temporary directory to save file
 
     tree_match_func : `str` or `callable`
@@ -176,17 +180,17 @@ def assert_roundtrip_tree(*args, **kwargs):
 
 def _assert_roundtrip_tree(
     tree,
-    tmpdir,
+    tmp_path,
     *,
     asdf_check_func=None,
     raw_yaml_check_func=None,
     write_options={},
     init_options={},
     extensions=None,
-    tree_match_func="assert_equal"
+    tree_match_func="assert_equal",
 ):
 
-    fname = str(tmpdir.join("test.asdf"))
+    fname = os.path.join(str(tmp_path), "test.asdf")
 
     # First, test writing/reading a BytesIO buffer
     buff = io.BytesIO()
@@ -306,11 +310,11 @@ def yaml_to_asdf(yaml_content, yaml_headers=True, standard_version=None):
 
     if yaml_headers:
         buff.write(
-            """#ASDF {0}
-#ASDF_STANDARD {1}
-%YAML {2}
+            """#ASDF {}
+#ASDF_STANDARD {}
+%YAML {}
 %TAG ! tag:stsci.edu:asdf/
---- !core/asdf-{3}
+--- !core/asdf-{}
 """.format(
                 file_format_version, standard_version, yaml_version, tree_version
             ).encode(
@@ -366,7 +370,7 @@ def display_warnings(_warnings):
 
     msg = "Unexpected warning(s) occurred:\n"
     for warning in _warnings:
-        msg += "{}:{}: {}: {}\n".format(warning.filename, warning.lineno, warning.category.__name__, warning.message)
+        msg += f"{warning.filename}:{warning.lineno}: {warning.category.__name__}: {warning.message}\n"
     return msg
 
 
@@ -430,7 +434,7 @@ def _assert_extension_type_correctness(extension, extension_type, resolver):
         # but shares a tag with that class, so it isn't really a distinct type.
         return
 
-    assert extension_type.name is not None, "{} must set the 'name' class attribute".format(extension_type.__name__)
+    assert extension_type.name is not None, f"{extension_type.__name__} must set the 'name' class attribute"
 
     # Currently ExtensionType sets a default version of 1.0.0,
     # but we want to encourage an explicit version on the subclass.
@@ -438,13 +442,33 @@ def _assert_extension_type_correctness(extension, extension_type, resolver):
         extension_type.__name__
     )
 
-    for check_type in extension_type.versioned_siblings + [extension_type]:
+    # check the default version
+    types_to_check = [extension_type]
+
+    # Adding or updating a schema/type version might involve updating multiple
+    # packages. This can result in types without schema and schema without types
+    # for the development version of the asdf-standard. To account for this,
+    # don't include versioned siblings of types with versions that are not
+    # in one of the asdf-standard versions in supported_versions (excluding the
+    # current development version).
+    asdf_standard_versions = supported_versions.copy()
+    if asdf_standard_development_version in asdf_standard_versions:
+        asdf_standard_versions.remove(asdf_standard_development_version)
+    for sibling in extension_type.versioned_siblings:
+        tag_base, version = split_tag_version(sibling.yaml_tag)
+        for asdf_standard_version in asdf_standard_versions:
+            vm = get_version_map(asdf_standard_version)
+            if tag_base in vm["tags"] and AsdfVersion(vm["tags"][tag_base]) == version:
+                types_to_check.append(sibling)
+                break
+
+    for check_type in types_to_check:
         schema_location = resolver(check_type.yaml_tag)
 
         assert schema_location is not None, (
-            "{} supports tag, {}, ".format(extension_type.__name__, check_type.yaml_tag)
+            f"{extension_type.__name__} supports tag, {check_type.yaml_tag}, "
             + "but tag does not resolve.  Check the tag_mapping and uri_mapping "
-            + "properties on the related extension ({}).".format(extension_type.__name__)
+            + f"properties on the related extension ({extension_type.__name__})."
         )
 
         if schema_location not in asdf.get_config().resource_manager:
@@ -453,7 +477,7 @@ def _assert_extension_type_correctness(extension, extension_type, resolver):
                     yaml.safe_load(f.read())
             except Exception:
                 assert False, (
-                    "{} supports tag, {}, ".format(extension_type.__name__, check_type.yaml_tag)
-                    + "which resolves to schema at {}, but ".format(schema_location)
+                    f"{extension_type.__name__} supports tag, {check_type.yaml_tag}, "
+                    + f"which resolves to schema at {schema_location}, but "
                     + "schema cannot be read."
                 )
