@@ -1,26 +1,24 @@
 import pytest
 from packaging.specifiers import SpecifierSet
 
-from asdf.extension import (
-    Extension,
-    ExtensionProxy,
-    ManifestExtension,
-    ExtensionManager,
-    get_cached_extension_manager,
-    TagDefinition,
-    Converter,
-    ConverterProxy,
-    Compressor,
-    AsdfExtension,
-    BuiltinExtension,
-    get_cached_asdf_extension_list
-)
-
 from asdf import config_context
 from asdf.exceptions import AsdfDeprecationWarning
-from asdf.types import CustomType
-
+from asdf.extension import (
+    AsdfExtension,
+    BuiltinExtension,
+    Compressor,
+    Converter,
+    ConverterProxy,
+    Extension,
+    ExtensionManager,
+    ExtensionProxy,
+    ManifestExtension,
+    TagDefinition,
+    get_cached_asdf_extension_list,
+    get_cached_extension_manager,
+)
 from asdf.tests.helpers import assert_extension_correctness
+from asdf.types import CustomType
 
 
 def test_builtin_extension():
@@ -120,11 +118,12 @@ class FullConverter(MinimumConverter):
 
 class MinimalCompressor(Compressor):
     def compress(data):
-        return b''
+        return b""
 
     @property
     def label(self):
-        return b'mini'
+        return b"mini"
+
 
 # Some dummy types for testing converters:
 class FooType:
@@ -191,21 +190,14 @@ def test_extension_proxy():
     assert subclassed_proxy.class_name == "asdf.tests.test_extension.MinimumExtensionSubclassed"
 
     # Test with all properties present:
-    converters = [
-        MinimumConverter(
-            tags=["asdf://somewhere.org/extensions/full/tags/foo-*"],
-            types=[]
-        )
-    ]
-    compressors = [
-        MinimalCompressor()
-    ]
+    converters = [MinimumConverter(tags=["asdf://somewhere.org/extensions/full/tags/foo-*"], types=[])]
+    compressors = [MinimalCompressor()]
     extension = FullExtension(
         converters=converters,
         compressors=compressors,
         asdf_standard_requirement=">=1.4.0",
         tags=["asdf://somewhere.org/extensions/full/tags/foo-1.0"],
-        legacy_class_names=["foo.extensions.SomeOldExtensionClass"]
+        legacy_class_names=["foo.extensions.SomeOldExtensionClass"],
     )
     proxy = ExtensionProxy(extension, package_name="foo", package_version="1.2.3")
 
@@ -237,7 +229,7 @@ def test_extension_proxy():
     with pytest.raises(TypeError):
         ExtensionProxy(FullExtension(compressors=[object()]))
 
-    # Unparseable ASDF Standard requirement:
+    # Unparsable ASDF Standard requirement:
     with pytest.raises(ValueError):
         ExtensionProxy(FullExtension(asdf_standard_requirement="asdf-standard >= 1.4.0"))
 
@@ -263,7 +255,7 @@ def test_extension_proxy_tags():
         foo_tag_uri,
         schema_uris="asdf://somewhere.org/extensions/full/schemas/foo-1.0",
         title="Some tag title",
-        description="Some tag description"
+        description="Some tag description",
     )
 
     bar_tag_uri = "asdf://somewhere.org/extensions/full/tags/bar-1.0"
@@ -271,7 +263,7 @@ def test_extension_proxy_tags():
         bar_tag_uri,
         schema_uris="asdf://somewhere.org/extensions/full/schemas/bar-1.0",
         title="Some other tag title",
-        description="Some other tag description"
+        description="Some other tag description",
     )
 
     # The converter should return only the tags
@@ -358,11 +350,9 @@ def test_extension_manager():
         tags=[
             "asdf://somewhere.org/extensions/full/tags/baz-*",
         ],
-        types=[
-            BazType
-        ],
+        types=[BazType],
     )
-    converter3= FullConverter(
+    converter3 = FullConverter(
         tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-*",
         ],
@@ -376,13 +366,13 @@ def test_extension_manager():
         tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-1.0",
             "asdf://somewhere.org/extensions/full/tags/baz-1.0",
-        ]
+        ],
     )
     extension2 = FullExtension(
         converters=[converter3],
-        tags = [
+        tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-1.0",
-        ]
+        ],
     )
 
     manager = ExtensionManager([extension1, extension2])
@@ -399,8 +389,14 @@ def test_extension_manager():
     assert manager.handles_type(BarType) is True
     assert manager.handles_type(BazType) is True
 
-    assert manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/foo-1.0").tag_uri == "asdf://somewhere.org/extensions/full/tags/foo-1.0"
-    assert manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/baz-1.0").tag_uri == "asdf://somewhere.org/extensions/full/tags/baz-1.0"
+    assert (
+        manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/foo-1.0").tag_uri
+        == "asdf://somewhere.org/extensions/full/tags/foo-1.0"
+    )
+    assert (
+        manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/baz-1.0").tag_uri
+        == "asdf://somewhere.org/extensions/full/tags/baz-1.0"
+    )
     with pytest.raises(KeyError):
         manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/bar-1.0")
 
@@ -443,12 +439,18 @@ def test_tag_definition():
 
     tag_def = TagDefinition(
         "asdf://somewhere.org/extensions/foo/tags/foo-1.0",
-        schema_uris=["asdf://somewhere.org/extensions/foo/schemas/foo-1.0", "asdf://somewhere.org/extensions/foo/schemas/base-1.0"],
+        schema_uris=[
+            "asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
+            "asdf://somewhere.org/extensions/foo/schemas/base-1.0",
+        ],
         title="Some title",
         description="Some description",
     )
 
-    assert tag_def.schema_uris == ["asdf://somewhere.org/extensions/foo/schemas/foo-1.0", "asdf://somewhere.org/extensions/foo/schemas/base-1.0"]
+    assert tag_def.schema_uris == [
+        "asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
+        "asdf://somewhere.org/extensions/foo/schemas/base-1.0",
+    ]
     with pytest.warns(AsdfDeprecationWarning):
         with pytest.raises(RuntimeError):
             tag_def.schema_uri
@@ -508,10 +510,7 @@ def test_converter_proxy():
     assert proxy != ConverterProxy(MinimumConverter(), extension)
     assert proxy != ConverterProxy(converter, MinimumExtension())
     assert proxy in {ConverterProxy(converter, extension)}
-    assert proxy not in {
-        ConverterProxy(MinimumConverter(), extension),
-        ConverterProxy(converter, MinimumExtension())
-    }
+    assert proxy not in {ConverterProxy(MinimumConverter(), extension), ConverterProxy(converter, MinimumExtension())}
 
     # Check the __repr__:
     assert "class: asdf.tests.test_extension.MinimumConverter" in repr(proxy)
@@ -523,7 +522,7 @@ def test_converter_proxy():
             "asdf://somewhere.org/extensions/test/tags/foo-*",
             "asdf://somewhere.org/extensions/test/tags/bar-*",
         ],
-        types=[FooType, BarType]
+        types=[FooType, BarType],
     )
 
     extension = FullExtension(
@@ -532,13 +531,13 @@ def test_converter_proxy():
                 "asdf://somewhere.org/extensions/test/tags/foo-1.0",
                 schema_uris="asdf://somewhere.org/extensions/test/schemas/foo-1.0",
                 title="Foo tag title",
-                description="Foo tag description"
+                description="Foo tag description",
             ),
             TagDefinition(
                 "asdf://somewhere.org/extensions/test/tags/bar-1.0",
                 schema_uris="asdf://somewhere.org/extensions/test/schemas/bar-1.0",
                 title="Bar tag title",
-                description="Bar tag description"
+                description="Bar tag description",
             ),
         ]
     )
