@@ -1,14 +1,11 @@
 import copy
-import os
 
 import numpy as np
 import pytest
-from numpy.testing import assert_array_equal
-
-astropy = pytest.importorskip("astropy")
 from astropy.io import fits
 from astropy.table import Table
 from jsonschema.exceptions import ValidationError
+from numpy.testing import assert_array_equal
 
 import asdf
 from asdf import fits_embed, get_config
@@ -42,9 +39,9 @@ def create_asdf_in_fits(dtype):
 # write files that use the old convention of ImageHDU to store the ASDF file.
 @pytest.mark.parametrize("backwards_compat", [False, True])
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_embed_asdf_in_fits_file(tmpdir, backwards_compat, dtype):
-    fits_testfile = str(tmpdir.join("test.fits"))
-    asdf_testfile = str(tmpdir.join("test.asdf"))
+def test_embed_asdf_in_fits_file(tmp_path, backwards_compat, dtype):
+    fits_testfile = str(tmp_path / "test.fits")
+    asdf_testfile = str(tmp_path / "test.asdf")
 
     hdulist = fits.HDUList()
     hdulist.append(fits.ImageHDU(np.arange(512, dtype=dtype), name="SCI"))
@@ -88,15 +85,15 @@ def test_embed_asdf_in_fits_file(tmpdir, backwards_compat, dtype):
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_embed_asdf_in_fits_file_anonymous_extensions(tmpdir, dtype):
+def test_embed_asdf_in_fits_file_anonymous_extensions(tmp_path, dtype):
     # Write the AsdfInFits object out as a FITS file with ASDF extension
     asdf_in_fits = create_asdf_in_fits(dtype)
-    asdf_in_fits.write_to(os.path.join(str(tmpdir), "test.fits"))
+    asdf_in_fits.write_to(str(tmp_path / "test.fits"))
 
     ff2 = asdf.AsdfFile(asdf_in_fits.tree)
-    ff2.write_to(os.path.join(str(tmpdir), "plain.asdf"))
+    ff2.write_to(str(tmp_path / "plain.asdf"))
 
-    with fits.open(os.path.join(str(tmpdir), "test.fits")) as hdulist:
+    with fits.open(str(tmp_path / "test.fits")) as hdulist:
         assert len(hdulist) == 4
         assert [x.name for x in hdulist] == ["PRIMARY", "", "", "ASDF"]
         asdf_hdu = hdulist["ASDF"]
@@ -107,16 +104,16 @@ def test_embed_asdf_in_fits_file_anonymous_extensions(tmpdir, dtype):
             assert_tree_match(asdf_in_fits.tree, ff2.tree)
 
             ff = asdf.AsdfFile(copy.deepcopy(ff2.tree))
-            ff.write_to(os.path.join(str(tmpdir), "test.asdf"))
+            ff.write_to(str(tmp_path / "test.asdf"))
 
-    with asdf.open(os.path.join(str(tmpdir), "test.asdf")) as ff:
+    with asdf.open(str(tmp_path / "test.asdf")) as ff:
         assert_tree_match(asdf_in_fits.tree, ff.tree)
 
 
 @pytest.mark.xfail(reason="In-place update for ASDF-in-FITS does not currently work")
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_update_in_place(tmpdir, dtype):
-    tempfile = str(tmpdir.join("test.fits"))
+def test_update_in_place(tmp_path, dtype):
+    tempfile = str(tmp_path / "test.fits")
 
     # Create a file and write it out
     asdf_in_fits = create_asdf_in_fits(dtype)
@@ -134,9 +131,9 @@ def test_update_in_place(tmpdir, dtype):
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_update_and_write_new(tmpdir, dtype):
-    tempfile = str(tmpdir.join("test.fits"))
-    newfile = str(tmpdir.join("new.fits"))
+def test_update_and_write_new(tmp_path, dtype):
+    tempfile = str(tmp_path / "test.fits")
+    newfile = str(tmp_path / "new.fits")
 
     # Create a file and write it out
     asdf_in_fits = create_asdf_in_fits(dtype)
@@ -155,11 +152,11 @@ def test_update_and_write_new(tmpdir, dtype):
 
 @pytest.mark.xfail(reason="ASDF HDU implementation does not currently reseek after writing")
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_access_hdu_data_after_write(tmpdir, dtype):
+def test_access_hdu_data_after_write(tmp_path, dtype):
     # There is actually probably not a great reason to support this kind of
     # functionality, but I am adding a test here to record the failure for
     # posterity.
-    tempfile = str(tmpdir.join("test.fits"))
+    tempfile = str(tmp_path / "test.fits")
 
     asdf_in_fits = create_asdf_in_fits(dtype)
     asdf_in_fits.write_to(tempfile)
@@ -169,7 +166,7 @@ def test_access_hdu_data_after_write(tmpdir, dtype):
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_create_in_tree_first(tmpdir, dtype):
+def test_create_in_tree_first(tmp_path, dtype):
     tree = {
         "model": {
             "sci": {"data": np.arange(512, dtype=dtype), "wcs": "WCS info"},
@@ -183,14 +180,14 @@ def test_create_in_tree_first(tmpdir, dtype):
     hdulist.append(fits.ImageHDU(tree["model"]["dq"]["data"]))
     hdulist.append(fits.ImageHDU(tree["model"]["err"]["data"]))
 
-    tmpfile = os.path.join(str(tmpdir), "test.fits")
+    tmpfile = str(tmp_path / "test.fits")
     with fits_embed.AsdfInFits(hdulist, tree) as ff:
         ff.write_to(tmpfile)
 
     with asdf.AsdfFile(tree) as ff:
-        ff.write_to(os.path.join(str(tmpdir), "plain.asdf"))
+        ff.write_to(str(tmp_path / "plain.asdf"))
 
-    with asdf.open(os.path.join(str(tmpdir), "plain.asdf")) as ff:
+    with asdf.open(str(tmp_path / "plain.asdf")) as ff:
         assert_array_equal(ff.tree["model"]["sci"]["data"], np.arange(512, dtype=dtype))
 
     # This tests the changes that allow FITS files with ASDF extensions to be
@@ -208,9 +205,9 @@ def compare_asdfs(asdf0, asdf1):
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_asdf_in_fits_open(tmpdir, dtype):
+def test_asdf_in_fits_open(tmp_path, dtype):
     """Test the open method of AsdfInFits"""
-    tmpfile = os.path.join(str(tmpdir), "test.fits")
+    tmpfile = str(tmp_path / "test.fits")
     # Write the AsdfInFits object out as a FITS file with ASDF extension
     asdf_in_fits = create_asdf_in_fits(dtype)
     asdf_in_fits.write_to(tmpfile)
@@ -236,9 +233,9 @@ def test_asdf_in_fits_open(tmpdir, dtype):
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_asdf_open(tmpdir, dtype):
+def test_asdf_open(tmp_path, dtype):
     """Test the top-level open method of the asdf module"""
-    tmpfile = os.path.join(str(tmpdir), "test.fits")
+    tmpfile = str(tmp_path / "test.fits")
     # Write the AsdfInFits object out as a FITS file with ASDF extension
     asdf_in_fits = create_asdf_in_fits(dtype)
     asdf_in_fits.write_to(tmpfile)
@@ -258,8 +255,8 @@ def test_asdf_open(tmpdir, dtype):
             compare_asdfs(asdf_in_fits, ff)
 
 
-def test_validate_on_read(tmpdir):
-    tmpfile = str(tmpdir.join("invalid.fits"))
+def test_validate_on_read(tmp_path):
+    tmpfile = str(tmp_path / "invalid.fits")
 
     content = """
 invalid_software: !core/software-1.0.0
@@ -269,7 +266,7 @@ invalid_software: !core/software-1.0.0
     buff = yaml_to_asdf(content)
     hdul = fits.HDUList()
     data = np.array(buff.getbuffer(), dtype=np.uint8)[None, :]
-    fmt = "{}B".format(len(data[0]))
+    fmt = f"{len(data[0])}B"
     column = fits.Column(array=data, format=fmt, name="ASDF_METADATA")
     hdu = fits.BinTableHDU.from_columns([column], name="ASDF")
     hdul.append(hdu)
@@ -287,6 +284,17 @@ invalid_software: !core/software-1.0.0
             assert af["invalid_software"]["version"] == 3
 
 
+def test_bad_fits_input(tmp_path):
+    path = tmp_path / "test.fits"
+    # create an empty fits file
+    with open(path, "wb") as f:
+        f.write(asdf.constants.FITS_MAGIC)
+
+    with pytest.raises(ValueError):
+        with asdf_open(path):
+            pass
+
+
 def test_open_gzipped():
     testfile = get_test_data_path("asdf.fits.gz")
 
@@ -294,22 +302,10 @@ def test_open_gzipped():
         assert af.tree["stuff"].shape == (20, 20)
 
 
-@pytest.mark.filterwarnings("ignore::astropy.io.fits.verify.VerifyWarning")
-def test_bad_input(tmpdir):
-    """Make sure these functions behave properly with bad input"""
-    text_file = os.path.join(str(tmpdir), "test.txt")
-
-    with open(text_file, "w") as fh:
-        fh.write("I <3 ASDF!!!!!")
-
-    with pytest.raises(ValueError):
-        asdf_open(text_file)
-
-
 def test_version_mismatch_file():
     testfile = str(get_test_data_path("version_mismatch.fits"))
 
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with asdf.open(testfile, ignore_version_mismatch=False) as fits_handle:
             assert fits_handle.tree["a"] == complex(0j)
 
@@ -318,7 +314,7 @@ def test_version_mismatch_file():
         with asdf.open(testfile) as fits_handle:
             assert fits_handle.tree["a"] == complex(0j)
 
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with fits_embed.AsdfInFits.open(testfile, ignore_version_mismatch=False) as fits_handle:
             assert fits_handle.tree["a"] == complex(0j)
 
@@ -328,8 +324,8 @@ def test_version_mismatch_file():
             assert fits_handle.tree["a"] == complex(0j)
 
 
-def test_serialize_table(tmpdir):
-    tmpfile = str(tmpdir.join("table.fits"))
+def test_serialize_table(tmp_path):
+    tmpfile = str(tmp_path / "table.fits")
 
     data = np.random.random((10, 10))
     table = Table(data)
@@ -350,7 +346,7 @@ def test_serialize_table(tmpdir):
 def test_extension_check():
     testfile = get_test_data_path("extension_check.fits")
 
-    with pytest.warns(AsdfWarning, match="was created with extension class 'foo.bar.FooBar'"):
+    with pytest.warns(AsdfWarning, match=r"was created with extension class 'foo.bar.FooBar'"):
         with asdf.open(testfile):
             pass
 
@@ -365,8 +361,8 @@ def test_extension_check():
 
 
 @pytest.mark.parametrize("dtype", TEST_DTYPES)
-def test_verify_with_astropy(tmpdir, dtype):
-    tmpfile = str(tmpdir.join("asdf.fits"))
+def test_verify_with_astropy(tmp_path, dtype):
+    tmpfile = str(tmp_path / "asdf.fits")
 
     with create_asdf_in_fits(dtype) as aif:
         aif.write_to(tmpfile)
@@ -375,14 +371,14 @@ def test_verify_with_astropy(tmpdir, dtype):
         hdu.verify("exception")
 
 
-def test_dangling_file_handle(tmpdir):
+def test_dangling_file_handle(tmp_path):
     """
     This tests the bug fix introduced in #533. Without the bug fix, this test
     will fail when running the test suite with pytest-openfiles.
     """
     import gc
 
-    fits_filename = str(tmpdir.join("dangling.fits"))
+    fits_filename = str(tmp_path / "dangling.fits")
 
     # Create FITS file to use for test
     hdulist = fits.HDUList()
@@ -460,13 +456,46 @@ def test_array_view_compatible_dtype(tmp_path):
     data = np.arange(100, dtype=np.float64)
     hdul = fits.HDUList([fits.PrimaryHDU(), fits.ImageHDU(data)])
     with pytest.raises(
-        ValueError, match="ASDF has only limited support for serializing views over arrays stored in FITS HDUs"
+        ValueError, match=r"ASDF has only limited support for serializing views over arrays stored in FITS HDUs"
     ):
         with asdf.fits_embed.AsdfInFits(hdulist=hdul) as af:
             af["view"] = hdul[-1].data.view(np.int64)
             af.write_to(file_path)
 
 
+def test_hdu_link_independence(tmp_path):
+    """
+    As links between arrays and hdu items are made during
+    saving, it's possible that if this goes wrong links
+    might be made between multiple arrays and a single hdu.
+    In this case, modifying one array will change memory
+    shared with another array. This test creates a file
+    with multiple arrays, writes it to a fits file,
+    reads it back in and then modifies the contents of
+    each array to check for this possible errort.
+    """
+    asdf_in_fits = create_asdf_in_fits("f4")
+    # set all arrays to same values
+    asdf_in_fits["model"]["sci"]["data"][:] = 0
+    asdf_in_fits["model"]["dq"]["data"][:] = 0
+    asdf_in_fits["model"]["err"]["data"][:] = 0
+
+    fn0 = tmp_path / "test0.fits"
+
+    # write out the asdf in fits file
+    asdf_in_fits.write_to(str(fn0))
+
+    with asdf.open(fn0, mode="r") as aif:
+        # assign new values
+        aif["model"]["sci"]["data"][:] = 1
+        aif["model"]["dq"]["data"][:] = 2
+        aif["model"]["err"]["data"][:] = 3
+
+        assert np.all(aif["model"]["sci"]["data"] == 1)
+        assert np.all(aif["model"]["dq"]["data"] == 2)
+        assert np.all(aif["model"]["err"]["data"] == 3)
+
+
 def test_array_view_different_layout(tmp_path):
     """
     A view over the FITS array with a different memory layout
@@ -484,6 +513,35 @@ def test_array_view_different_layout(tmp_path):
         af["data"] = hdul[-1].data
         af["other"] = other_view
         with pytest.raises(
-            ValueError, match="ASDF has only limited support for serializing views over arrays stored in FITS HDUs"
+            ValueError, match=r"ASDF has only limited support for serializing views over arrays stored in FITS HDUs"
         ):
             af.write_to(file_path)
+
+
+def test_resave_breaks_hdulist_tree_array_link(tmp_path):
+    """
+    Test that writing, reading and rewriting an AsdfInFits file
+    maintains links between hdus and arrays in the asdf tree
+
+    If the link is broken, data can be duplicated (exist both
+    as a hdu and as an internal block in the asdf tree).
+
+    See issues:
+        https://github.com/asdf-format/asdf/issues/1232
+        https://github.com/spacetelescope/jwst/issues/7354
+        https://github.com/spacetelescope/jwst/issues/7274
+    """
+    file_path_1 = tmp_path / "test1.fits"
+    file_path_2 = tmp_path / "test2.fits"
+
+    af = create_asdf_in_fits("f4")
+    af.write_to(file_path_1)
+
+    with asdf.open(file_path_1) as af1:
+        af1.write_to(file_path_2)
+
+    # check that af1 (original write) and af2 (rewrite) do not contain internal blocks
+    with fits.open(file_path_1) as af1, fits.open(file_path_2) as af2:
+        for f in (af1, af2):
+            block_bytes = f["ASDF"].data.tobytes().split(b"...")[1].strip()
+            assert len(block_bytes) == 0
