@@ -3,6 +3,7 @@ import os
 import sys
 import urllib.request as urllib_request
 
+import fsspec
 import numpy as np
 import pytest
 
@@ -40,17 +41,17 @@ def _roundtrip(tree, get_write_fd, get_read_fd, write_options={}, read_options={
     return ff
 
 
-def test_mode_fail(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_mode_fail(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     with pytest.raises(ValueError):
         generic_io.get_file(path, mode="r+")
 
 
-def test_open(tmpdir, small_tree):
+def test_open(tmp_path, small_tree):
     from .. import open
 
-    path = os.path.join(str(tmpdir), "test.asdf")
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     # Simply tests the high-level "open" function
     ff = asdf.AsdfFile(small_tree)
@@ -59,8 +60,8 @@ def test_open(tmpdir, small_tree):
         helpers.assert_tree_match(ff2.tree, ff.tree)
 
 
-def test_path(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_path(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
         f = generic_io.get_file(path, mode="w")
@@ -85,8 +86,8 @@ def test_path(tree, tmpdir):
         assert isinstance(next(ff.blocks.internal_blocks)._data, np.core.memmap)
 
 
-def test_open2(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_open2(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
         f = generic_io.get_file(open(path, "wb"), mode="w", close=True)
@@ -106,55 +107,55 @@ def test_open2(tree, tmpdir):
         assert isinstance(next(ff.blocks.internal_blocks)._data, np.core.memmap)
 
 
-def test_open_fail(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_open_fail(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     with open(path, "w") as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, mode="w")
 
 
-def test_open_fail2(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_open_fail2(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
-    with io.open(path, "w") as fd:
+    with open(path, "w") as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, mode="w")
 
 
-def test_open_fail3(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_open_fail3(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     with open(path, "w") as fd:
         fd.write("\n\n\n")
 
-    with open(path, "r") as fd:
+    with open(path) as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, mode="r")
 
 
-def test_open_fail4(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_open_fail4(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     with open(path, "w") as fd:
         fd.write("\n\n\n")
 
-    with io.open(path, "r") as fd:
+    with open(path) as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, mode="r")
 
 
-def test_io_open(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_io_open(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
-        f = generic_io.get_file(io.open(path, "wb"), mode="w", close=True)
+        f = generic_io.get_file(open(path, "wb"), mode="w", close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
         return f
 
     def get_read_fd():
-        f = generic_io.get_file(io.open(path, "r+b"), mode="rw", close=True)
+        f = generic_io.get_file(open(path, "r+b"), mode="rw", close=True)
         assert isinstance(f, generic_io.RealFile)
         assert f._uri == util.filepath_to_url(path)
         return f
@@ -165,20 +166,20 @@ def test_io_open(tree, tmpdir):
         ff.tree["science_data"][0] = 42
 
 
-def test_close_underlying(tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_close_underlying(tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     with generic_io.get_file(open(path, "wb"), mode="w", close=True) as ff:
         pass
 
-    assert ff.is_closed() == True
-    assert ff._fd.closed == True
+    assert ff.is_closed() is True
+    assert ff._fd.closed is True
 
     with generic_io.get_file(open(path, "rb"), close=True) as ff2:
         pass
 
-    assert ff2.is_closed() == True
-    assert ff2._fd.closed == True
+    assert ff2.is_closed() is True
+    assert ff2._fd.closed is True
 
 
 def test_bytes_io(tree):
@@ -267,8 +268,8 @@ def test_http_connection(tree, httpserver):
         ff.tree["science_data"][0] == 42
 
 
-def test_exploded_filesystem(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_exploded_filesystem(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
         return generic_io.get_file(path, mode="w")
@@ -281,8 +282,8 @@ def test_exploded_filesystem(tree, tmpdir):
         assert len(list(ff.blocks.external_blocks)) == 2
 
 
-def test_exploded_filesystem_fail(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_exploded_filesystem_fail(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
         return generic_io.get_file(path, mode="w")
@@ -328,12 +329,12 @@ def test_exploded_stream_write(small_tree):
         ff.write_to(io.BytesIO(), all_array_storage="external")
 
 
-def test_exploded_stream_read(tmpdir, small_tree):
+def test_exploded_stream_read(tmp_path, small_tree):
     # Reading from an exploded input file should fail, but only once
     # the data block is accessed.  This behavior is important so that
     # the tree can still be accessed even if the data is missing.
 
-    path = os.path.join(str(tmpdir), "test.asdf")
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     ff = asdf.AsdfFile(small_tree)
     ff.write_to(path, all_array_storage="external")
@@ -347,24 +348,30 @@ def test_exploded_stream_read(tmpdir, small_tree):
                 ff.tree["science_data"][:]
 
 
-def test_unicode_open(tmpdir, small_tree):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_unicode_open(tmp_path, small_tree):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     ff = asdf.AsdfFile(small_tree)
 
     ff.write_to(path)
 
-    with io.open(path, "rt", encoding="utf-8") as fd:
+    with open(path, encoding="utf-8") as fd:
         with pytest.raises(ValueError):
             with asdf.open(fd):
                 pass
 
 
-def test_invalid_obj(tmpdir):
+def test_open_stdout():
+    """Test ability to open/write stdout as an output stream"""
+    with generic_io.get_file(sys.__stdout__, "w", close=True):
+        pass
+
+
+def test_invalid_obj(tmp_path):
     with pytest.raises(ValueError):
         generic_io.get_file(42)
 
-    path = os.path.join(str(tmpdir), "test.asdf")
+    path = os.path.join(str(tmp_path), "test.asdf")
     with generic_io.get_file(path, "w") as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, "r")
@@ -379,20 +386,17 @@ def test_invalid_obj(tmpdir):
         with pytest.raises(ValueError):
             generic_io.get_file(fd, "w")
 
-    with io.open(path, "rb") as fd:
+    with open(path, "rb") as fd:
         with pytest.raises(ValueError):
             generic_io.get_file(fd, "w")
 
-    with generic_io.get_file(sys.__stdout__, "w"):
-        pass
 
-
-def test_nonseekable_file(tmpdir):
+def test_nonseekable_file(tmp_path):
     base = io.IOBase
 
     class FileWrapper(base):
         def tell(self):
-            raise IOError()
+            raise OSError()
 
         def seekable(self):
             return False
@@ -403,12 +407,12 @@ def test_nonseekable_file(tmpdir):
         def writable(self):
             return True
 
-    with FileWrapper(os.path.join(str(tmpdir), "test.asdf"), "wb") as fd:
+    with FileWrapper(os.path.join(str(tmp_path), "test.asdf"), "wb") as fd:
         assert isinstance(generic_io.get_file(fd, "w"), generic_io.OutputStream)
         with pytest.raises(ValueError):
             generic_io.get_file(fd, "rw")
 
-    with FileWrapper(os.path.join(str(tmpdir), "test.asdf"), "rb") as fd:
+    with FileWrapper(os.path.join(str(tmp_path), "test.asdf"), "rb") as fd:
         assert isinstance(generic_io.get_file(fd, "r"), generic_io.InputStream)
 
 
@@ -422,13 +426,17 @@ def test_resolve_uri(protocol):
     Confirm that the patched urllib.parse is handling
     asdf:// URIs correctly.
     """
-    assert generic_io.resolve_uri(
-        "{}://somewhere.org/some-schema".format(protocol), "#/definitions/foo"
-    ) == "{}://somewhere.org/some-schema#/definitions/foo".format(protocol)
+    assert (
+        generic_io.resolve_uri(f"{protocol}://somewhere.org/some-schema", "#/definitions/foo")
+        == f"{protocol}://somewhere.org/some-schema#/definitions/foo"
+    )
 
-    assert generic_io.resolve_uri(
-        "{}://somewhere.org/path/to/some-schema".format(protocol), "../../some/other/path/to/some-other-schema"
-    ) == "{}://somewhere.org/some/other/path/to/some-other-schema".format(protocol)
+    assert (
+        generic_io.resolve_uri(
+            f"{protocol}://somewhere.org/path/to/some-schema", "../../some/other/path/to/some-other-schema"
+        )
+        == f"{protocol}://somewhere.org/some/other/path/to/some-other-schema"
+    )
 
 
 def test_arbitrary_file_object():
@@ -476,13 +484,13 @@ def test_arbitrary_file_object():
         generic_io.get_file(Writer(buff), "r")
 
 
-def test_check_bytes(tmpdir):
-    with io.open(os.path.join(str(tmpdir), "test.asdf"), "w", encoding="utf-8") as fd:
+def test_check_bytes(tmp_path):
+    with open(os.path.join(str(tmp_path), "test.asdf"), "w", encoding="utf-8") as fd:
         assert generic_io._check_bytes(fd, "r") is False
         assert generic_io._check_bytes(fd, "rw") is False
         assert generic_io._check_bytes(fd, "w") is False
 
-    with io.open(os.path.join(str(tmpdir), "test.asdf"), "wb") as fd:
+    with open(os.path.join(str(tmp_path), "test.asdf"), "wb") as fd:
         assert generic_io._check_bytes(fd, "r") is True
         assert generic_io._check_bytes(fd, "rw") is True
         assert generic_io._check_bytes(fd, "w") is True
@@ -716,8 +724,8 @@ def test_truncated_reader():
     assert tr.read() == b""
 
 
-def test_blocksize(tree, tmpdir):
-    path = os.path.join(str(tmpdir), "test.asdf")
+def test_blocksize(tree, tmp_path):
+    path = os.path.join(str(tmp_path), "test.asdf")
 
     def get_write_fd():
         f = generic_io.get_file(open(path, "wb"), mode="w", close=True)
@@ -732,3 +740,75 @@ def test_blocksize(tree, tmpdir):
         config.io_block_size = 1233  # make sure everything works with a strange blocksize
         with _roundtrip(tree, get_write_fd, get_read_fd) as ff:
             assert ff._fd.block_size == 1233
+
+
+def test_io_subclasses(tmp_path):
+    ref = b"0123456789"
+
+    b = io.BytesIO(b"0123456789")
+    b.seek(0)
+    f = generic_io.get_file(b)
+    r = f.read(len(ref))
+    assert r == ref, (r, ref)
+    f.close()
+
+    b = io.BytesIO(b"0123456789")
+    b.seek(0)
+    br = io.BufferedReader(io.BytesIO(ref))
+    f = generic_io.get_file(b)
+    assert r == ref, (r, ref)
+    f.close()
+
+    b = io.BytesIO(b"")
+    bw = io.BufferedWriter(b)
+    f = generic_io.get_file(bw, mode="w")
+    f.write(ref)
+    b.seek(0)
+    r = b.read(len(ref))
+    assert r == ref, (r, ref)
+    f.close()
+
+    b = io.BytesIO(b"")
+    br = io.BufferedRandom(b)
+    f = generic_io.get_file(br, mode="rw")
+    f.write(ref)
+    f.seek(0)
+    r = f.read(len(ref))
+    assert r == ref, (r, ref)
+    f.close()
+
+
+def test_fsspec(tmp_path):
+    """
+    Issue #1146 reported errors when opening a fsspec 'file'
+    This is a regression test for the fix in PR #1226
+    """
+    ref = b"01234567890"
+    fn = tmp_path / "test"
+
+    with fsspec.open(fn, mode="bw+") as f:
+        f.write(ref)
+        f.seek(0)
+        gf = generic_io.get_file(f)
+        r = gf.read(len(ref))
+        assert r == ref, (r, ref)
+
+
+@pytest.mark.remote_data
+def test_fsspec_http(httpserver):
+    """
+    Issue #1146 reported errors when opening a fsspec url (using the http
+    filesystem)
+    This is a regression test for the fix in PR #1228
+    """
+    ref = b"01234567890"
+    path = os.path.join(httpserver.tmpdir, "test")
+
+    with open(path, "wb") as f:
+        f.write(ref)
+
+    fn = httpserver.url + "test"
+    with fsspec.open(fn) as f:
+        gf = generic_io.get_file(f)
+        r = gf.read(len(ref))
+        assert r == ref, (r, ref)
