@@ -5,7 +5,7 @@ from asdf.exceptions import AsdfConversionWarning, AsdfWarning
 from asdf.tests.helpers import assert_roundtrip_tree
 
 
-def test_conversion_error(tmpdir):
+def test_conversion_error(tmp_path):
     class FooType(types.CustomType):
         name = "foo"
 
@@ -41,5 +41,5 @@ def test_conversion_error(tmpdir):
     tree = dict(foo=foo)
 
     with pytest.raises(AsdfConversionWarning):
-        with pytest.warns(AsdfWarning, match="Unable to locate schema file"):
-            assert_roundtrip_tree(tree, tmpdir, extensions=FooExtension())
+        with pytest.warns(AsdfWarning, match=r"Unable to locate schema file"):
+            assert_roundtrip_tree(tree, tmp_path, extensions=FooExtension())
