@@ -61,7 +61,7 @@ def test_read_json_schema():
     schema.check_schema(schema_tree)
 
 
-def test_load_schema(tmpdir):
+def test_load_schema(tmp_path):
     schema_def = """
 %YAML 1.1
 ---
@@ -77,14 +77,14 @@ properties:
 required: [foobar]
 ...
     """
-    schema_path = tmpdir.join("nugatory.yaml")
-    schema_path.write(schema_def.encode())
+    schema_path = tmp_path / "nugatory.yaml"
+    schema_path.write_bytes(schema_def.encode())
 
     schema_tree = schema.load_schema(str(schema_path), resolve_references=True)
     schema.check_schema(schema_tree)
 
 
-def test_load_schema_with_full_tag(tmpdir):
+def test_load_schema_with_full_tag(tmp_path):
     schema_def = """
 %YAML 1.1
 ---
@@ -100,14 +100,14 @@ properties:
 required: [foobar]
 ...
     """
-    schema_path = tmpdir.join("nugatory.yaml")
-    schema_path.write(schema_def.encode())
+    schema_path = tmp_path / "nugatory.yaml"
+    schema_path.write_bytes(schema_def.encode())
 
     schema_tree = schema.load_schema(str(schema_path), resolve_references=True)
     schema.check_schema(schema_tree)
 
 
-def test_load_schema_with_tag_address(tmpdir):
+def test_load_schema_with_tag_address(tmp_path):
     schema_def = """
 %YAML 1.1
 %TAG !asdf! tag:stsci.edu:asdf/
@@ -124,14 +124,14 @@ properties:
 required: [foobar]
 ...
     """
-    schema_path = tmpdir.join("nugatory.yaml")
-    schema_path.write(schema_def.encode())
+    schema_path = tmp_path / "nugatory.yaml"
+    schema_path.write_bytes(schema_def.encode())
 
     schema_tree = schema.load_schema(str(schema_path), resolve_references=True)
     schema.check_schema(schema_tree)
 
 
-def test_load_schema_with_file_url(tmpdir):
+def test_load_schema_with_file_url(tmp_path):
     schema_def = """
 %YAML 1.1
 %TAG !asdf! tag:stsci.edu:asdf/
@@ -150,8 +150,8 @@ required: [foobar]
     """.format(
         extension.get_default_resolver()("tag:stsci.edu:asdf/core/ndarray-1.0.0")
     )
-    schema_path = tmpdir.join("nugatory.yaml")
-    schema_path.write(schema_def.encode())
+    schema_path = tmp_path / "nugatory.yaml"
+    schema_path.write_bytes(schema_def.encode())
 
     schema_tree = schema.load_schema(str(schema_path), resolve_references=True)
     schema.check_schema(schema_tree)
@@ -263,7 +263,7 @@ def test_asdf_file_resolver_hashing():
 
 
 def test_load_schema_from_resource_mapping():
-    content = """
+    content = b"""
 id: http://somewhere.org/schemas/razmataz-1.0.0
 type: object
 properties:
@@ -271,9 +271,7 @@ properties:
     type: string
   bar:
     type: boolean
-""".encode(
-        "utf-8"
-    )
+"""
 
     get_config().add_resource_mapping({"http://somewhere.org/schemas/razmataz-1.0.0": content})
 
@@ -362,7 +360,7 @@ custom: !<tag:nowhere.org:custom/custom-1.0.0>
     # This should cause a warning but not an error because without explicitly
     # providing an extension, our custom type will not be recognized and will
     # simply be converted to a raw type.
-    with pytest.warns(AsdfConversionWarning, match="tag:nowhere.org:custom/custom-1.0.0"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:nowhere.org:custom/custom-1.0.0"):
         with asdf.open(buff):
             pass
 
@@ -474,7 +472,7 @@ custom: !<tag:nowhere.org:custom/default-1.0.0>
         assert ff.tree["custom"]["j"]["l"] == 362
 
     buff.seek(0)
-    with pytest.warns(AsdfDeprecationWarning, match="do_not_fill_defaults"):
+    with pytest.warns(AsdfDeprecationWarning, match=r"do_not_fill_defaults"):
         with asdf.open(buff, extensions=[DefaultTypeExtension()], do_not_fill_defaults=True) as ff:
             assert "a" not in ff.tree["custom"]
             assert "c" not in ff.tree["custom"]["b"]
@@ -655,8 +653,8 @@ def test_max_min_literals(num):
 
 @pytest.mark.parametrize("num", [constants.MAX_NUMBER + 1, constants.MIN_NUMBER - 1])
 @pytest.mark.parametrize("ttype", ["val", "list", "key"])
-def test_max_min_literals_write(num, ttype, tmpdir):
-    outfile = tmpdir / "test.asdf"
+def test_max_min_literals_write(num, ttype, tmp_path):
+    outfile = tmp_path / "test.asdf"
     af = asdf.AsdfFile()
 
     # Validation doesn't occur here, so no warning/error will be raised.
@@ -679,7 +677,7 @@ def test_read_large_literal(value):
 
     buff = helpers.yaml_to_asdf(yaml)
 
-    with pytest.warns(AsdfWarning, match="Invalid integer literal value"):
+    with pytest.warns(AsdfWarning, match=r"Invalid integer literal value"):
         with asdf.open(buff) as af:
             assert af["integer"] == value
 
@@ -687,7 +685,7 @@ def test_read_large_literal(value):
 
     buff = helpers.yaml_to_asdf(yaml)
 
-    with pytest.warns(AsdfWarning, match="Invalid integer literal value"):
+    with pytest.warns(AsdfWarning, match=r"Invalid integer literal value"):
         with asdf.open(buff) as af:
             assert af[value] == "foo"
 
@@ -718,7 +716,7 @@ def test_mapping_supported_key_types(keys, version):
 )
 def test_mapping_unsupported_key_types(keys, version):
     for key in keys:
-        with pytest.raises(ValidationError, match="Mapping key .* is not permitted"):
+        with pytest.raises(ValidationError, match=r"Mapping key .* is not permitted"):
             af = asdf.AsdfFile({key: "value"}, version=version)
             buff = io.BytesIO()
             af.write_to(buff)
@@ -760,7 +758,7 @@ def test_nested_array():
             schema.validate(b, schema=s)
 
 
-def test_nested_array_yaml(tmpdir):
+def test_nested_array_yaml(tmp_path):
     schema_def = """
 %YAML 1.1
 ---
@@ -778,8 +776,8 @@ properties:
       maxItems: 3
 ...
     """
-    schema_path = tmpdir.join("nested.yaml")
-    schema_path.write(schema_def.encode())
+    schema_path = tmp_path / "nested.yaml"
+    schema_path.write_bytes(schema_def.encode())
 
     schema_tree = schema.load_schema(str(schema_path))
     schema.check_schema(schema_tree)
@@ -821,12 +819,12 @@ custom: !<tag:nowhere.org:custom/missing-1.1.0>
   b: {foo: 42}
     """
     buff = helpers.yaml_to_asdf(yaml)
-    with pytest.warns(AsdfConversionWarning, match="Failed to convert tag:nowhere.org:custom/missing-1.1.0"):
+    with pytest.warns(AsdfConversionWarning, match=r"Failed to convert tag:nowhere.org:custom/missing-1.1.0"):
         with asdf.open(buff, extensions=[DefaultTypeExtension()]) as ff:
             assert ff.tree["custom"]["b"]["foo"] == 42
 
 
-def test_assert_roundtrip_with_extension(tmpdir):
+def test_assert_roundtrip_with_extension(tmp_path):
     called_custom_assert_equal = [False]
 
     class CustomType(dict, types.CustomType):
@@ -850,14 +848,14 @@ def test_assert_roundtrip_with_extension(tmpdir):
         assert isinstance(ff.tree["custom"], CustomType)
 
     with helpers.assert_no_warnings():
-        helpers.assert_roundtrip_tree(tree, tmpdir, extensions=[CustomTypeExtension()])
+        helpers.assert_roundtrip_tree(tree, tmp_path, extensions=[CustomTypeExtension()])
 
     assert called_custom_assert_equal[0] is True
 
 
-def test_custom_validation_bad(tmpdir):
+def test_custom_validation_bad(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree does not conform to the custom schema
     tree = {"stuff": 42, "other_stuff": "hello"}
@@ -881,9 +879,9 @@ def test_custom_validation_bad(tmpdir):
             pass
 
 
-def test_custom_validation_good(tmpdir):
+def test_custom_validation_good(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree conforms to the custom schema
     tree = {"foo": {"x": 42, "y": 10}, "bar": {"a": "hello", "b": "banjo"}}
@@ -895,7 +893,7 @@ def test_custom_validation_good(tmpdir):
         pass
 
 
-def test_custom_validation_pathlib(tmpdir):
+def test_custom_validation_pathlib(tmp_path):
     """
     Make sure custom schema paths can be pathlib.Path objects
 
@@ -904,7 +902,7 @@ def test_custom_validation_pathlib(tmpdir):
     from pathlib import Path
 
     custom_schema_path = Path(helpers.get_test_data_path("custom_schema.yaml"))
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree conforms to the custom schema
     tree = {"foo": {"x": 42, "y": 10}, "bar": {"a": "hello", "b": "banjo"}}
@@ -916,9 +914,9 @@ def test_custom_validation_pathlib(tmpdir):
         pass
 
 
-def test_custom_validation_with_definitions_good(tmpdir):
+def test_custom_validation_with_definitions_good(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema_definitions.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree conforms to the custom schema
     tree = {"thing": {"biz": "hello", "baz": "world"}}
@@ -930,9 +928,9 @@ def test_custom_validation_with_definitions_good(tmpdir):
         pass
 
 
-def test_custom_validation_with_definitions_bad(tmpdir):
+def test_custom_validation_with_definitions_bad(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema_definitions.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree does NOT conform to the custom schema
     tree = {"forb": {"biz": "hello", "baz": "world"}}
@@ -956,9 +954,9 @@ def test_custom_validation_with_definitions_bad(tmpdir):
             pass
 
 
-def test_custom_validation_with_external_ref_good(tmpdir):
+def test_custom_validation_with_external_ref_good(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema_external_ref.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree conforms to the custom schema
     tree = {"foo": asdf.tags.core.Software(name="Microsoft Windows", version="95")}
@@ -970,9 +968,9 @@ def test_custom_validation_with_external_ref_good(tmpdir):
         pass
 
 
-def test_custom_validation_with_external_ref_bad(tmpdir):
+def test_custom_validation_with_external_ref_bad(tmp_path):
     custom_schema_path = helpers.get_test_data_path("custom_schema_external_ref.yaml")
-    asdf_file = str(tmpdir.join("out.asdf"))
+    asdf_file = str(tmp_path / "out.asdf")
 
     # This tree does not conform to the custom schema
     tree = {"foo": False}
@@ -1010,7 +1008,7 @@ def test_load_schema_resolve_local_refs_deprecated():
         schema.load_schema(custom_schema_path, resolve_local_refs=True)
 
 
-def test_nonexistent_tag(tmpdir):
+def test_nonexistent_tag(tmp_path):
     """
     This tests the case where a node is tagged with a type that apparently
     comes from an extension that is known, but the type itself can't be found.
@@ -1031,7 +1029,7 @@ a: !core/doesnt_exist-1.0.0
     """
 
     buff = helpers.yaml_to_asdf(yaml)
-    with pytest.warns(AsdfWarning, match="Unable to locate schema file"):
+    with pytest.warns(AsdfWarning, match=r"Unable to locate schema file"):
         with asdf.open(buff) as af:
             assert str(af["a"]) == "hello"
 
@@ -1042,7 +1040,7 @@ a: !<tag:nowhere.org:custom/doesnt_exist-1.0.0>
   """
 
     buff = helpers.yaml_to_asdf(yaml)
-    with pytest.warns(AsdfWarning, match="Unable to locate schema file"):
+    with pytest.warns(AsdfWarning, match=r"Unable to locate schema file"):
         with asdf.open(buff, extensions=CustomExtension()) as af:
             assert str(af["a"]) == "hello"
 
