@@ -1,7 +1,7 @@
 import re
 
-import pytest
 import numpy as np
+import pytest
 
 from asdf import AsdfFile
 
@@ -12,7 +12,7 @@ def asdf_file():
         "foo": 42,
         "nested": {"foo": 24, "foible": "whoops", "folicle": "yup", "moo": 24},
         "bar": "hello",
-        "list": [{"index": 0}, {"index": 1}, {"index": 2}]
+        "list": [{"index": 0}, {"index": 1}, {"index": 2}],
     }
     return AsdfFile(tree)
 
@@ -101,9 +101,7 @@ def test_by_value_with_ndarray():
     """
     Check some edge cases when comparing integers and booleans to numpy arrays.
     """
-    tree = {
-        "foo": np.arange(10)
-    }
+    tree = {"foo": np.arange(10)}
     af = AsdfFile(tree)
     result = af.search(value=True)
     assert len(result.nodes) == 0
@@ -191,3 +189,17 @@ def test_recursive_tree():
     result.replace("zap")
     assert af["foo"]["bar"] == "zap"
     assert af["foo"]["nested"]["bar"] == "zap"
+
+
+def test_search():
+    tree = dict(foo=42, bar="hello", baz=np.arange(20))
+    af = AsdfFile(tree)
+
+    result = af.search("foo")
+    assert result.node == 42
+
+    result = af.search(type="ndarray")
+    assert (result.node == tree["baz"]).all()
+
+    result = af.search(value="hello")
+    assert result.node == "hello"
