@@ -1,5 +1,4 @@
 import io
-import os
 from fractions import Fraction
 
 import pytest
@@ -160,13 +159,13 @@ a: !core/complex-42.0.0
     """
 
     buff = helpers.yaml_to_asdf(yaml)
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with asdf.open(buff, ignore_version_mismatch=False) as ff:
             assert isinstance(ff.tree["a"], complex)
 
     # Make sure warning is repeatable
     buff.seek(0)
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with asdf.open(buff, ignore_version_mismatch=False) as ff:
             assert isinstance(ff.tree["a"], complex)
 
@@ -184,13 +183,13 @@ a: !core/complex-1.0.1
     """
 
     buff = helpers.yaml_to_asdf(yaml)
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with asdf.open(buff, ignore_version_mismatch=False) as ff:
             assert isinstance(ff.tree["a"], complex)
 
 
-def test_version_mismatch_file(tmpdir):
-    testfile = os.path.join(str(tmpdir), "mismatch.asdf")
+def test_version_mismatch_file(tmp_path):
+    testfile = str(tmp_path / "mismatch.asdf")
     yaml = """
 a: !core/complex-42.0.0
   0j
@@ -202,7 +201,7 @@ a: !core/complex-42.0.0
 
     expected_uri = util.filepath_to_url(str(testfile))
 
-    with pytest.warns(AsdfConversionWarning, match="tag:stsci.edu:asdf/core/complex"):
+    with pytest.warns(AsdfConversionWarning, match=r"tag:stsci.edu:asdf/core/complex"):
         with asdf.open(testfile, ignore_version_mismatch=False) as ff:
             assert ff._fname == expected_uri
             assert isinstance(ff.tree["a"], complex)
@@ -317,10 +316,13 @@ def test_longest_match():
         def url_mapping(self):
             return [("http://stsci.edu/schemas/asdf/core/", "FOOBAR/{url_suffix}")]
 
-    l = extension.AsdfExtensionList([extension.BuiltinExtension(), FancyComplexExtension()])
+    extension_list = extension.AsdfExtensionList([extension.BuiltinExtension(), FancyComplexExtension()])
 
-    assert l.url_mapping("http://stsci.edu/schemas/asdf/core/asdf-1.0.0") == "FOOBAR/asdf-1.0.0"
-    assert l.url_mapping("http://stsci.edu/schemas/asdf/transform/transform-1.0.0") != "FOOBAR/transform-1.0.0"
+    assert extension_list.url_mapping("http://stsci.edu/schemas/asdf/core/asdf-1.0.0") == "FOOBAR/asdf-1.0.0"
+    assert (
+        extension_list.url_mapping("http://stsci.edu/schemas/asdf/transform/transform-1.0.0")
+        != "FOOBAR/transform-1.0.0"
+    )
 
 
 def test_module_versioning():
@@ -340,9 +342,9 @@ def test_module_versioning():
     # perhaps an unfortunate acroynm
     dhcp = DoesntHaveCorrectPytest()
 
-    assert nmt.has_required_modules == False
-    assert hcp.has_required_modules == True
-    assert dhcp.has_required_modules == False
+    assert nmt.has_required_modules is False
+    assert hcp.has_required_modules is True
+    assert dhcp.has_required_modules is False
 
 
 def test_undefined_tag():
@@ -387,13 +389,16 @@ undefined_data:
 
 
 def test_newer_tag():
-    # This test simulates a scenario where newer versions of CustomFlow
-    # provides different keyword parameters that the older schema and tag class
-    # do not account for. We want to test whether ASDF can handle this problem
-    # gracefully and still provide meaningful data as output. The test case is
-    # fairly contrived but we want to test whether ASDF can handle backwards
-    # compatibility even when an explicit tag class for different versions of a
-    # schema is not available.
+    """
+    This test simulates a scenario where newer versions of CustomFlow
+    provides different keyword parameters that the older schema and tag class
+    do not account for. We want to test whether ASDF can handle this problem
+    gracefully and still provide meaningful data as output. The test case is
+    fairly contrived but we want to test whether ASDF can handle backwards
+    compatibility even when an explicit tag class for different versions of a
+    schema is not available.
+    """
+
     class CustomFlow:
         def __init__(self, c=None, d=None):
             self.c = c
@@ -441,7 +446,7 @@ flow_thing:
     old_buff = helpers.yaml_to_asdf(old_yaml)
     # We expect this warning since it will not be possible to convert version
     # 1.0.0 of CustomFlow to a CustomType (by design, for testing purposes).
-    with pytest.warns(AsdfConversionWarning, match="Failed to convert tag:nowhere.org:custom/custom_flow-1.0.0"):
+    with pytest.warns(AsdfConversionWarning, match=r"Failed to convert tag:nowhere.org:custom/custom_flow-1.0.0"):
         asdf.open(old_buff, extensions=CustomFlowExtension())
 
 
@@ -449,47 +454,47 @@ def test_incompatible_version_check():
     class TestType0(types.CustomType):
         supported_versions = versioning.AsdfSpec(">=1.2.0")
 
-    assert TestType0.incompatible_version("1.1.0") == True
-    assert TestType0.incompatible_version("1.2.0") == False
-    assert TestType0.incompatible_version("2.0.1") == False
+    assert TestType0.incompatible_version("1.1.0") is True
+    assert TestType0.incompatible_version("1.2.0") is False
+    assert TestType0.incompatible_version("2.0.1") is False
 
     class TestType1(types.CustomType):
         supported_versions = versioning.AsdfVersion("1.0.0")
 
-    assert TestType1.incompatible_version("1.0.0") == False
-    assert TestType1.incompatible_version("1.1.0") == True
+    assert TestType1.incompatible_version("1.0.0") is False
+    assert TestType1.incompatible_version("1.1.0") is True
 
     class TestType2(types.CustomType):
         supported_versions = "1.0.0"
 
-    assert TestType2.incompatible_version("1.0.0") == False
-    assert TestType2.incompatible_version("1.1.0") == True
+    assert TestType2.incompatible_version("1.0.0") is False
+    assert TestType2.incompatible_version("1.1.0") is True
 
     class TestType3(types.CustomType):
         # This doesn't make much sense, but it's just for the sake of example
         supported_versions = ["1.0.0", versioning.AsdfSpec(">=2.0.0")]
 
-    assert TestType3.incompatible_version("1.0.0") == False
-    assert TestType3.incompatible_version("1.1.0") == True
-    assert TestType3.incompatible_version("2.0.0") == False
-    assert TestType3.incompatible_version("2.0.1") == False
+    assert TestType3.incompatible_version("1.0.0") is False
+    assert TestType3.incompatible_version("1.1.0") is True
+    assert TestType3.incompatible_version("2.0.0") is False
+    assert TestType3.incompatible_version("2.0.1") is False
 
     class TestType4(types.CustomType):
         supported_versions = ["1.0.0", versioning.AsdfVersion("1.1.0")]
 
-    assert TestType4.incompatible_version("1.0.0") == False
-    assert TestType4.incompatible_version("1.0.1") == True
-    assert TestType4.incompatible_version("1.1.0") == False
-    assert TestType4.incompatible_version("1.1.1") == True
+    assert TestType4.incompatible_version("1.0.0") is False
+    assert TestType4.incompatible_version("1.0.1") is True
+    assert TestType4.incompatible_version("1.1.0") is False
+    assert TestType4.incompatible_version("1.1.1") is True
 
     class TestType5(types.CustomType):
         supported_versions = [versioning.AsdfSpec("<1.0.0"), versioning.AsdfSpec(">=2.0.0")]
 
-    assert TestType5.incompatible_version("0.9.9") == False
-    assert TestType5.incompatible_version("2.0.0") == False
-    assert TestType5.incompatible_version("2.0.1") == False
-    assert TestType5.incompatible_version("1.0.0") == True
-    assert TestType5.incompatible_version("1.1.0") == True
+    assert TestType5.incompatible_version("0.9.9") is False
+    assert TestType5.incompatible_version("2.0.0") is False
+    assert TestType5.incompatible_version("2.0.1") is False
+    assert TestType5.incompatible_version("1.0.0") is True
+    assert TestType5.incompatible_version("1.1.0") is True
 
     with pytest.raises(ValueError):
 
@@ -583,14 +588,14 @@ flow_thing:
     buff = helpers.yaml_to_asdf(yaml)
 
     with pytest.warns(
-        AsdfConversionWarning, match="Version 1.1.0 of tag:nowhere.org:custom/custom_flow is not compatible"
+        AsdfConversionWarning, match=r"Version 1.1.0 of tag:nowhere.org:custom/custom_flow is not compatible"
     ):
         asdf.open(buff, extensions=CustomFlowExtension())
 
 
-def test_tag_without_schema(tmpdir):
+def test_tag_without_schema(tmp_path):
 
-    tmpfile = str(tmpdir.join("foo.asdf"))
+    tmpfile = str(tmp_path / "foo.asdf")
 
     class FooType(types.CustomType):
         name = "foo"
@@ -626,27 +631,60 @@ def test_tag_without_schema(tmpdir):
     foo = FooType("hello", 42)
     tree = dict(foo=foo)
 
-    with pytest.warns(AsdfWarning, match="Unable to locate schema file"):
+    with pytest.warns(AsdfWarning, match=r"Unable to locate schema file"):
         with asdf.AsdfFile(tree, extensions=FooExtension()) as af:
             af.write_to(tmpfile)
 
-    with pytest.warns(AsdfWarning, match="Unable to locate schema file"):
+    with pytest.warns(AsdfWarning, match=r"Unable to locate schema file"):
         with asdf.AsdfFile(tree, extensions=FooExtension()) as ff:
             assert isinstance(ff.tree["foo"], FooType)
             assert ff.tree["foo"] == tree["foo"]
 
 
-def test_custom_reference_cycle(tmpdir):
+def test_custom_reference_cycle(tmp_path):
     f1 = FractionWithInverse(3, 5)
     f2 = FractionWithInverse(5, 3)
     f1.inverse = f2
     f2.inverse = f1
     tree = {"fraction": f1}
 
-    path = str(tmpdir.join("with_inverse.asdf"))
+    path = str(tmp_path / "with_inverse.asdf")
 
     with asdf.AsdfFile(tree, extensions=FractionWithInverseExtension()) as af:
         af.write_to(path)
 
     with asdf.open(path, extensions=FractionWithInverseExtension()) as af:
         assert af["fraction"].inverse.inverse is af["fraction"]
+
+
+def test_super_use_in_versioned_subclass():
+    """
+    Test fix for issue: https://github.com/asdf-format/asdf/issues/1245
+
+    Legacy extensions cannot use super in subclasses of CustomType
+    that define supported_versions due to the metaclasses inability
+    to create distinct __classcell__ closures.
+    """
+
+    class Foo:
+        def __init__(self, bar):
+            self.bar = bar
+
+    with pytest.raises(RuntimeError, match=r".* ExtensionTypeMeta .* __classcell__ .*"):
+
+        class FooType(asdf.CustomType):
+            name = "foo"
+            version = (1, 0, 0)
+            supported_versions = [(1, 1, 0), (1, 2, 0)]
+            types = [Foo]
+
+            @classmethod
+            def to_tree(cls, node, ctx):
+                return {"bar": node.bar}
+
+            @classmethod
+            def from_tree(cls, tree, ctx):
+                return Foo(tree["bar"])
+
+            def __getattribute__(self, name):
+                return super().__getattribute__(name)
