@@ -4,7 +4,23 @@ import pytest
 
 from asdf.extension import default_extensions
 from asdf.schema import load_schema
-from asdf.versioning import AsdfSpec, AsdfVersion, get_version_map, join_tag_version, supported_versions
+from asdf.versioning import (
+    AsdfSpec,
+    AsdfVersion,
+    asdf_standard_development_version,
+    default_version,
+    get_version_map,
+    join_tag_version,
+    supported_versions,
+)
+
+
+def test_default_in_supported_versions():
+    assert default_version in supported_versions
+
+
+def test_development_is_not_default():
+    assert default_version != asdf_standard_development_version
 
 
 def test_version_constructor():
@@ -65,8 +81,8 @@ def test_version_and_version_inequality():
 
     assert ver0 < ver1 < ver2 < ver3 < ver4 < ver5 < ver6 < ver7
     assert ver7 > ver6 > ver5 > ver4 > ver3 > ver2 > ver1 > ver0
-    assert (ver0 < ver1 < ver2 < ver4 < ver3 < ver5 < ver6 < ver7) == False
-    assert (ver7 > ver6 > ver5 > ver3 > ver4 > ver2 > ver1 > ver0) == False
+    assert (ver0 < ver1 < ver2 < ver4 < ver3 < ver5 < ver6 < ver7) is False
+    assert (ver7 > ver6 > ver5 > ver3 > ver4 > ver2 > ver1 > ver0) is False
 
     assert ver0 <= ver1 <= ver2 <= ver3 <= ver4 <= ver5 <= ver6 <= ver7
     assert ver7 >= ver6 >= ver5 >= ver4 >= ver3 >= ver2 >= ver1 >= ver0
@@ -79,8 +95,8 @@ def test_version_and_string_inequality():
     assert version > "1.0.1"
     assert version > "1.1.0"
     assert version > "1.1.1"
-    assert (version > "2.0.0") == False
-    assert (version < "2.0.0") == False
+    assert (version > "2.0.0") is False
+    assert (version < "2.0.0") is False
     assert version < "2.0.1"
     assert version < "2.1.0"
     assert version < "2.1.1"
@@ -99,8 +115,8 @@ def test_version_and_string_inequality():
     assert "1.0.1" < version
     assert "1.1.0" < version
     assert "1.1.1" < version
-    assert ("2.0.0" < version) == False
-    assert ("2.0.0" > version) == False
+    assert ("2.0.0" < version) is False
+    assert ("2.0.0" > version) is False
     assert "2.0.1" > version
     assert "2.1.0" > version
     assert "2.1.1" > version
@@ -123,8 +139,8 @@ def test_version_and_tuple_inequality():
     assert version > (1, 0, 1)
     assert version > (1, 1, 0)
     assert version > (1, 1, 1)
-    assert (version > (2, 0, 0)) == False
-    assert (version < (2, 0, 0)) == False
+    assert (version > (2, 0, 0)) is False
+    assert (version < (2, 0, 0)) is False
     assert version < (2, 0, 1)
     assert version < (2, 1, 0)
     assert version < (2, 1, 1)
@@ -143,8 +159,8 @@ def test_version_and_tuple_inequality():
     assert (1, 0, 1) < version
     assert (1, 1, 0) < version
     assert (1, 1, 1) < version
-    assert ((2, 0, 0) < version) == False
-    assert ((2, 0, 0) > version) == False
+    assert ((2, 0, 0) < version) is False
+    assert ((2, 0, 0) > version) is False
     assert (2, 0, 1) > version
     assert (2, 1, 0) > version
     assert (2, 1, 1) > version
@@ -175,7 +191,7 @@ def test_spec_version_select():
     versions = [AsdfVersion(x) for x in ["1.0.0", "1.0.9", "1.1.0", "1.2.0"]]
     assert spec.select(versions) == "1.2.0"
     assert spec.select(versions[:-1]) == "1.1.0"
-    assert spec.select(versions[:-2]) == None
+    assert spec.select(versions[:-2]) is None
 
 
 def test_spec_version_filter():
@@ -201,7 +217,7 @@ def test_spec_string_select():
     versions = ["1.0.0", "1.0.9", "1.1.0", "1.2.0"]
     assert spec.select(versions) == "1.2.0"
     assert spec.select(versions[:-1]) == "1.1.0"
-    assert spec.select(versions[:-2]) == None
+    assert spec.select(versions[:-2]) is None
 
 
 def test_spec_string_filter():
@@ -227,7 +243,7 @@ def test_spec_tuple_select():
     versions = [(1, 0, 0), (1, 0, 9), (1, 1, 0), (1, 2, 0)]
     assert spec.select(versions) == "1.2.0"
     assert spec.select(versions[:-1]) == "1.1.0"
-    assert spec.select(versions[:-2]) == None
+    assert spec.select(versions[:-2]) is None
 
 
 def test_spec_tuple_filter():
@@ -260,45 +276,102 @@ def test_spec_equal():
     assert (1, 3, 0) == spec
 
 
-@pytest.mark.parametrize("version", supported_versions)
-def test_version_map_core_support(version):
-    _test_version_map_support(version, "core")
+def _standard_versioned_tags():
+    versions = supported_versions
+    schema_types = ["core", "standard"]
+    for version in versions:
+        vm = get_version_map(version)
+        for schema_type in schema_types:
+            for tag_base, tag_version in vm[schema_type].items():
+                tag = join_tag_version(tag_base, tag_version)
+                value = (str(version), schema_type, tag)
+                yield value
 
 
-@pytest.mark.parametrize("version", supported_versions)
-@pytest.mark.xfail(reason="astropy does not yet explicitly support older schema versions", strict=True)
-def test_version_map_standard_support(version):
-    _test_version_map_support(version, "standard")
+@pytest.fixture
+def xfail_version_map_support_cases(request):
+    tag = request.getfixturevalue("tag")
+    version = request.getfixturevalue("version")
+    if (version, tag) in [
+        ("1.6.0", "tag:stsci.edu:asdf/core/column-1.1.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/core/table-1.1.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/fits/fits-1.1.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/time/time-1.2.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/unit/defunit-1.1.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/unit/quantity-1.2.0"),
+        ("1.6.0", "tag:stsci.edu:asdf/unit/unit-1.1.0"),
+        ("1.5.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/celestial_frame-1.1.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/composite_frame-1.1.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/icrs_coord-1.1.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/spectral_frame-1.1.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/step-1.2.0"),
+        ("1.4.0", "tag:stsci.edu:asdf/wcs/wcs-1.2.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/celestial_frame-1.1.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/composite_frame-1.1.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/icrs_coord-1.1.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/spectral_frame-1.1.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/step-1.1.0"),
+        ("1.3.0", "tag:stsci.edu:asdf/wcs/wcs-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/celestial_frame-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/composite_frame-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/icrs_coord-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/spectral_frame-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/step-1.1.0"),
+        ("1.2.0", "tag:stsci.edu:asdf/wcs/wcs-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/celestial_frame-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/composite_frame-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/icrs_coord-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/spectral_frame-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/step-1.1.0"),
+        ("1.1.0", "tag:stsci.edu:asdf/wcs/wcs-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/unit/defunit-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/wcs/celestial_frame-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/wcs/composite_frame-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/wcs/spectral_frame-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/wcs/step-1.0.0"),
+        ("1.0.0", "tag:stsci.edu:asdf/wcs/wcs-1.0.0"),
+    ]:
+        request.node.add_marker(
+            pytest.mark.xfail(reason="astropy does not yet explicitly support older schema versions", strict=True)
+        )
 
 
-def _test_version_map_support(version, schema_type):
-    vm = get_version_map(version)
-
+@pytest.mark.parametrize("version, schema_type, tag", list(_standard_versioned_tags()))
+@pytest.mark.usefixtures("xfail_version_map_support_cases")
+def test_version_map_support(version, schema_type, tag):
     type_index = default_extensions.extension_list.type_index
 
     class MockContext:
         def __init__(self):
             self._fname = None
 
+        def _warn_tag_mismatch(self, *args, **kwargs):
+            pass
+
     ctx = MockContext()
 
-    for tag_base, tag_version in vm[schema_type].items():
-        tag = join_tag_version(tag_base, tag_version)
-
-        try:
-            load_schema(tag)
-        except Exception:
-            assert False, "ASDF Standard version {} requires support for ".format(
-                version
-            ) + "{}, but the corresponding schema cannot be loaded.".format(tag)
-
-        extension_type = type_index.from_yaml_tag(ctx, tag)
-        assert extension_type is not None, "ASDF Standard version {} requires support for ".format(
-            version
-        ) + "{}, but no ExtensionType exists to support that tag.".format(tag)
-
-        assert extension_type.yaml_tag == tag, (
-            "ASDF Standard version {} requires support for ".format(version)
-            + "{}, but no ExtensionType exists that explicitly ".format(tag)
-            + "supports that version."
+    try:
+        load_schema(tag)
+    except Exception:
+        assert False, (
+            f"ASDF Standard version {version} requires support for "
+            + f"{tag}, but the corresponding schema cannot be loaded."
         )
+
+    extension_type = type_index.from_yaml_tag(ctx, tag)
+    assert extension_type is not None, (
+        f"ASDF Standard version {version} requires support for "
+        + f"{tag}, but no ExtensionType exists to support that tag."
+    )
+
+    assert extension_type.yaml_tag == tag, (
+        f"ASDF Standard version {version} requires support for "
+        + f"{tag}, but no ExtensionType exists that explicitly "
+        + "supports that version."
+    )
