@@ -9,7 +9,7 @@ from contextlib import contextmanager
 from . import tagged
 from .exceptions import AsdfWarning
 
-__all__ = ["walk", "iter_tree", "walk_and_modify", "get_children", "is_container", "PendingValue"]
+__all__ = ["walk", "iter_tree", "walk_and_modify", "get_children", "is_container", "PendingValue", "RemoveNode"]
 
 
 def walk(top, callback):
@@ -68,14 +68,12 @@ def iter_tree(top):
         if isinstance(tree, (list, tuple)):
             seen.add(tree_id)
             for val in tree:
-                for sub in recurse(val):
-                    yield sub
+                yield from recurse(val)
             seen.remove(tree_id)
         elif isinstance(tree, dict):
             seen.add(tree_id)
             for val in tree.values():
-                for sub in recurse(val):
-                    yield sub
+                yield from recurse(val)
             seen.remove(tree_id)
 
         yield tree
@@ -237,7 +235,7 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
         - a json id (optional)
 
         It may return a different instance in order to modify the
-        tree.  If the singleton instance `asdf.treeutil.RemoveNode`
+        tree.  If the singleton instance `~asdf.treeutil._RemoveNode`
         is returned, the node will be removed from the tree.
 
         The json id is the context under which any relative URLs
@@ -255,7 +253,7 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
     ignore_implicit_conversion : bool
         Controls whether warnings should be issued when implicitly converting a
         given type instance in the tree into a serializable object. The primary
-        case for this is currently `namedtuple`.
+        case for this is currently ``namedtuple``.
 
         Defaults to `False`.
 
@@ -358,11 +356,10 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
                 result._tag = node._tag
         except TypeError:
             # The derived class signature is different, so simply store the
-            # list representing the contents. Currently this is primarly
+            # list representing the contents. Currently this is primarily
             # intended to handle namedtuple and NamedTuple instances.
             if not ignore_implicit_conversion:
-                msg = "Failed to serialize instance of {}, converting to list instead"
-                warnings.warn(msg.format(type(node)), AsdfWarning)
+                warnings.warn(f"Failed to serialize instance of {type(node)}, converting to list instead", AsdfWarning)
             result = contents
 
         return result
@@ -387,7 +384,7 @@ def walk_and_modify(top, callback, ignore_implicit_conversion=False, postorder=T
             # to the same object id.
             return _context[node]
 
-        # Inform the context that we're going to start modifing
+        # Inform the context that we're going to start modifying
         # this node.
         with _context.pending(node):
             # Take note of the "id" field, in case we're modifying
