@@ -3,23 +3,18 @@ from collections import OrderedDict
 from types import GeneratorType
 
 import numpy as np
-
 import yaml
 
-from . import schema
-from . import tagged
-from . import treeutil
-from . import util
-from .constants import YAML_TAG_PREFIX, STSCI_SCHEMA_TAG_BASE
-from .versioning import split_tag_version
+from . import schema, tagged, treeutil, util
+from .constants import STSCI_SCHEMA_TAG_BASE, YAML_TAG_PREFIX
 from .exceptions import AsdfConversionWarning
 from .tags.core import AsdfObject
+from .versioning import split_tag_version
+
+__all__ = ["custom_tree_to_tagged_tree", "tagged_tree_to_custom_tree"]
 
 
-__all__ = ['custom_tree_to_tagged_tree', 'tagged_tree_to_custom_tree']
-
-
-if getattr(yaml, '__with_libyaml__', None):  # pragma: no cover
+if getattr(yaml, "__with_libyaml__", None):  # pragma: no cover
     _yaml_base_dumper = yaml.CSafeDumper
     _yaml_base_loader = yaml.CSafeLoader
 else:  # pragma: no cover
@@ -27,7 +22,7 @@ else:  # pragma: no cover
     _yaml_base_loader = yaml.SafeLoader
 
 
-YAML_OMAP_TAG = YAML_TAG_PREFIX + 'omap'
+YAML_OMAP_TAG = YAML_TAG_PREFIX + "omap"
 
 
 # ----------------------------------------------------------------------
@@ -41,36 +36,31 @@ class AsdfDumper(_yaml_base_dumper):
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs['default_flow_style'] = None
+        kwargs["default_flow_style"] = None
         super().__init__(*args, **kwargs)
 
     def represent_data(self, data):
-        node = super(AsdfDumper, self).represent_data(data)
+        node = super().represent_data(data)
 
-        tag_name = getattr(data, '_tag', None)
+        tag_name = getattr(data, "_tag", None)
         if tag_name is not None:
             node.tag = tag_name
 
         return node
 
 
-_flow_style_map = {
-    'flow': True,
-    'block': False
-}
+_flow_style_map = {"flow": True, "block": False}
 
 
 def represent_sequence(dumper, sequence):
     flow_style = _flow_style_map.get(sequence.flow_style, None)
     sequence = sequence.data
-    return super(AsdfDumper, dumper).represent_sequence(
-        None, sequence, flow_style)
+    return super(AsdfDumper, dumper).represent_sequence(None, sequence, flow_style)
 
 
 def represent_mapping(dumper, mapping):
     flow_style = _flow_style_map.get(mapping.flow_style, None)
-    node = super(AsdfDumper, dumper).represent_mapping(
-        None, mapping.data, flow_style)
+    node = super(AsdfDumper, dumper).represent_mapping(None, mapping.data, flow_style)
 
     if mapping.property_order:
         values = node.value
@@ -93,17 +83,12 @@ def represent_mapping(dumper, mapping):
     return node
 
 
-_style_map = {
-    'inline': '"',
-    'folded': '>',
-    'literal': '|'
-}
+_style_map = {"inline": '"', "folded": ">", "literal": "|"}
 
 
 def represent_scalar(dumper, value):
     style = _style_map.get(value.style, None)
-    return super(AsdfDumper, dumper).represent_scalar(
-        None, value.data, style)
+    return super(AsdfDumper, dumper).represent_scalar(None, value.data, style)
 
 
 def represent_ordered_mapping(dumper, tag, data):
@@ -114,16 +99,13 @@ def represent_ordered_mapping(dumper, tag, data):
     # TODO: Need to see if I can figure out a mechanism so that classes that
     # use this representer can specify which values should use flow style
     values = []
-    node = yaml.SequenceNode(tag, values,
-                             flow_style=dumper.default_flow_style)
+    node = yaml.SequenceNode(tag, values, flow_style=dumper.default_flow_style)
     if dumper.alias_key is not None:
         dumper.represented_objects[dumper.alias_key] = node
     for key, value in data.items():
         key_item = dumper.represent_data(key)
         value_item = dumper.represent_data(value)
-        node_item = yaml.MappingNode(YAML_OMAP_TAG,
-                                     [(key_item, value_item)],
-                                     flow_style=False)
+        node_item = yaml.MappingNode(YAML_OMAP_TAG, [(key_item, value_item)], flow_style=False)
         values.append(node_item)
     return node
 
@@ -146,12 +128,14 @@ for scalar_type in util.iter_subclasses(np.floating):
 for scalar_type in util.iter_subclasses(np.integer):
     AsdfDumper.add_representer(scalar_type, AsdfDumper.represent_int)
 
+
 def represent_numpy_str(dumper, data):
     # The CSafeDumper implementation will raise an error if it
     # doesn't recognize data as a string.  The Python SafeDumper
     # has no problem with np.str_.
     return dumper.represent_str(str(data))
 
+
 AsdfDumper.add_representer(np.str_, represent_numpy_str)
 AsdfDumper.add_representer(np.bytes_, AsdfDumper.represent_binary)
 
@@ -191,17 +175,27 @@ class AsdfLoader(_yaml_base_loader):
         omap = OrderedDict()
         yield omap
         if not isinstance(node, yaml.SequenceNode):
-            raise yaml.ConstructorError("while constructing an ordered map", node.start_mark,
-                    "expected a sequence, but found %s" % node.id, node.start_mark)
+            raise yaml.ConstructorError(
+                "while constructing an ordered map",
+                node.start_mark,
+                "expected a sequence, but found %s" % node.id,
+                node.start_mark,
+            )
         for subnode in node.value:
             if not isinstance(subnode, yaml.MappingNode):
-                raise yaml.ConstructorError("while constructing an ordered map", node.start_mark,
-                        "expected a mapping of length 1, but found %s" % subnode.id,
-                        subnode.start_mark)
+                raise yaml.ConstructorError(
+                    "while constructing an ordered map",
+                    node.start_mark,
+                    f"expected a mapping of length 1, but found {subnode.id}",
+                    subnode.start_mark,
+                )
             if len(subnode.value) != 1:
-                raise yaml.ConstructorError("while constructing an ordered map", node.start_mark,
-                        "expected a single mapping item, but found %d items" % len(subnode.value),
-                        subnode.start_mark)
+                raise yaml.ConstructorError(
+                    "while constructing an ordered map",
+                    node.start_mark,
+                    f"expected a single mapping item, but found {len(subnode.value): %d} items",
+                    subnode.start_mark,
+                )
             key_node, value_node = subnode.value[0]
             key = self.construct_object(key_node)
             value = self.construct_object(value_node)
@@ -244,9 +238,7 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
             tagged_node = tagged.TaggedString(node)
             tagged_node._tag = tag
         else:
-            raise TypeError(
-                "Converter returned illegal node type: {}".format(util.get_class_name(node))
-            )
+            raise TypeError(f"Converter returned illegal node type: {util.get_class_name(node)}")
 
         _serialization_context._mark_extension_used(converter.extension)
 
@@ -259,9 +251,7 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
             return _convert_obj(obj)
         else:
             tag = ctx.type_index.from_custom_type(
-                type(obj),
-                ctx.version_string,
-                _serialization_context=_serialization_context
+                type(obj), ctx.version_string, _serialization_context=_serialization_context
             )
 
             if tag is not None:
@@ -293,7 +283,7 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
         if force_raw_types:
             return node
 
-        tag = getattr(node, '_tag', None)
+        tag = getattr(node, "_tag", None)
         if tag is None:
             return node
 
@@ -307,8 +297,10 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
         # This means the tag did not correspond to any type in our type index.
         if tag_type is None:
             if not ctx._ignore_unrecognized_tag:
-                warnings.warn("{} is not recognized, converting to raw Python "
-                    "data structure".format(tag), AsdfConversionWarning)
+                warnings.warn(
+                    f"{tag} is not recognized, converting to raw Python data structure",
+                    AsdfConversionWarning,
+                )
             return node
 
         tag_name, tag_version = split_tag_version(tag)
@@ -316,10 +308,10 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
         # compatible with the associated tag class implementation, but the
         # version we found does not fit that description.
         if tag_type.incompatible_version(tag_version):
-            warnings.warn("Version {} of {} is not compatible with any "
-                "existing tag implementations".format(
-                    tag_version, tag_name),
-                AsdfConversionWarning)
+            warnings.warn(
+                f"Version {tag_version} of {tag_name} is not compatible with any existing tag implementations",
+                AsdfConversionWarning,
+            )
             return node
 
         # If a tag class does not explicitly list compatible versions, then all
@@ -330,9 +322,10 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
         try:
             return tag_type.from_tree_tagged(node, ctx)
         except TypeError as err:
-            warnings.warn("Failed to convert {} to custom type (detail: {}). "
-                "Using raw Python data structure instead".format(tag, err),
-                AsdfConversionWarning)
+            warnings.warn(
+                f"Failed to convert {tag} to custom type (detail: {err}). " "Using raw Python data structure instead",
+                AsdfConversionWarning,
+            )
 
         return node
 
@@ -358,7 +351,7 @@ def load_tree(stream):
     """
     # The following call to yaml.load is safe because we're
     # using a loader that inherits from pyyaml's SafeLoader.
-    return yaml.load(stream, Loader=AsdfLoader) # nosec
+    return yaml.load(stream, Loader=AsdfLoader)  # nosec
 
 
 def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
@@ -389,14 +382,13 @@ def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
     if type(tree) is not AsdfObject:
         raise TypeError("Root node of ASDF tree must be of type AsdfObject")
 
-    tags = {'!': STSCI_SCHEMA_TAG_BASE + '/'}
+    tags = {"!": STSCI_SCHEMA_TAG_BASE + "/"}
     tree = custom_tree_to_tagged_tree(tree, ctx, _serialization_context=_serialization_context)
     if tree_finalizer is not None:
         tree_finalizer(tree)
     schema.validate(tree, ctx)
 
-    yaml_version = tuple(
-        int(x) for x in ctx.version_map['YAML_VERSION'].split('.'))
+    yaml_version = tuple(int(x) for x in ctx.version_map["YAML_VERSION"].split("."))
 
     # add yaml %TAG definitions from extensions
     if _serialization_context:
@@ -406,8 +398,13 @@ def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
                     tags[key] = val
 
     yaml.dump_all(
-        [tree], stream=fd, Dumper=AsdfDumper,
-        explicit_start=True, explicit_end=True,
+        [tree],
+        stream=fd,
+        Dumper=AsdfDumper,
+        explicit_start=True,
+        explicit_end=True,
         version=yaml_version,
-        allow_unicode=True, encoding='utf-8',
-        tags=tags)
+        allow_unicode=True,
+        encoding="utf-8",
+        tags=tags,
+    )
