@@ -1,11 +1,16 @@
+import numpy as np
+
 import asdf
 from asdf.versioning import supported_versions
-import numpy as np
 
 
 def generate_file(path, version):
     if version not in supported_versions:
-        raise ValueError("ASDF Standard version {} is not supported by version {} of the asdf library".format(version, asdf.__version__))
+        raise ValueError(
+            "ASDF Standard version {} is not supported by version {} of the asdf library".format(
+                version, asdf.__version__
+            )
+        )
 
     af = asdf.AsdfFile({"array": np.ones((8, 16))}, version=version)
     af.write_to(path)
